BULBASAUR = "Bulbasaur"
IVYSAUR = "Ivysaur"
VENUSAUR = "Venusaur"
CHARMANDER = "Charmander"
CHARMELEON = "Charmeleon"
CHARIZARD = "Charizard"
SQUIRTLE = "Squirtle"
WARTORTLE = "Wartortle"
BLASTOISE = "Blastoise"
CATERPIE = "Caterpie"
METAPOD = "Metapod"
BUTTERFREE = "Butterfree"
WEEDLE = "Weedle"
KAKUNA = "Kakuna"
BEEDRILL = "Beedrill"
PIDGEY = "Pidgey"
PIDGEOTTO = "Pidgeotto"
PIDGEOT = "Pidgeot"
RATTATA = "Rattata"
RATICATE = "Raticate"
SPEAROW = "Spearow"
FEAROW = "Fearow"
EKANS = "Ekans"
ARBOK = "Arbok"
PIKACHU = "Pikachu"
RAICHU = "Raichu"
SANDSHREW = "Sandshrew"
SANDSLASH = "Sandslash"
NIDORAN_F = "Nidoran♀"
NIDORINA = "Nidorina"
NIDOQUEEN = "Nidoqueen"
NIDORAN_M = "Nidoran♂"
NIDORINO = "Nidorino"
NIDOKING = "Nidoking"
CLEFAIRY = "Clefairy"
CLEFABLE = "Clefable"
VULPIX = "Vulpix"
NINETALES = "Ninetales"
JIGGLYPUFF = "Jigglypuff"
WIGGLYTUFF = "Wigglytuff"
ZUBAT = "Zubat"
GOLBAT = "Golbat"
ODDISH = "Oddish"
GLOOM = "Gloom"
VILEPLUME = "Vileplume"
PARAS = "Paras"
PARASECT = "Parasect"
VENONAT = "Venonat"
VENOMOTH = "Venomoth"
DIGLETT = "Diglett"
DUGTRIO = "Dugtrio"
MEOWTH = "Meowth"
PERSIAN = "Persian"
PSYDUCK = "Psyduck"
GOLDUCK = "Golduck"
MANKEY = "Mankey"
PRIMEAPE = "Primeape"
GROWLITHE = "Growlithe"
ARCANINE = "Arcanine"
POLIWAG = "Poliwag"
POLIWHIRL = "Poliwhirl"
POLIWRATH = "Poliwrath"
ABRA = "Abra"
KADABRA = "Kadabra"
ALAKAZAM = "Alakazam"
MACHOP = "Machop"
MACHOKE = "Machoke"
MACHAMP = "Machamp"
BELLSPROUT = "Bellsprout"
WEEPINBELL = "Weepinbell"
VICTREEBEL = "Victreebel"
TENTACOOL = "Tentacool"
TENTACRUEL = "Tentacruel"
GEODUDE = "Geodude"
GRAVELER = "Graveler"
GOLEM = "Golem"
PONYTA = "Ponyta"
RAPIDASH = "Rapidash"
SLOWPOKE = "Slowpoke"
SLOWBRO = "Slowbro"
MAGNEMITE = "Magnemite"
MAGNETON = "Magneton"
FARFETCHD = "Farfetch'd"
DODUO = "Doduo"
DODRIO = "Dodrio"
SEEL = "Seel"
DEWGONG = "Dewgong"
GRIMER = "Grimer"
MUK = "Muk"
SHELLDER = "Shellder"
CLOYSTER = "Cloyster"
GASTLY = "Gastly"
HAUNTER = "Haunter"
GENGAR = "Gengar"
ONIX = "Onix"
DROWZEE = "Drowzee"
HYPNO = "Hypno"
KRABBY = "Krabby"
KINGLER = "Kingler"
VOLTORB = "Voltorb"
ELECTRODE = "Electrode"
EXEGGCUTE = "Exeggcute"
EXEGGUTOR = "Exeggutor"
CUBONE = "Cubone"
MAROWAK = "Marowak"
HITMONLEE = "Hitmonlee"
HITMONCHAN = "Hitmonchan"
LICKITUNG = "Lickitung"
KOFFING = "Koffing"
WEEZING = "Weezing"
RHYHORN = "Rhyhorn"
RHYDON = "Rhydon"
CHANSEY = "Chansey"
TANGELA = "Tangela"
KANGASKHAN = "Kangaskhan"
HORSEA = "Horsea"
SEADRA = "Seadra"
GOLDEEN = "Goldeen"
SEAKING = "Seaking"
STARYU = "Staryu"
STARMIE = "Starmie"
MRMIME = "Mr. Mime"
SCYTHER = "Scyther"
JYNX = "Jynx"
ELECTABUZZ = "Electabuzz"
MAGMAR = "Magmar"
PINSIR = "Pinsir"
TAUROS = "Tauros"
MAGIKARP = "Magikarp"
GYARADOS = "Gyarados"
LAPRAS = "Lapras"
DITTO = "Ditto"
EEVEE = "Eevee"
VAPOREON = "Vaporeon"
JOLTEON = "Jolteon"
FLAREON = "Flareon"
PORYGON = "Porygon"
OMANYTE = "Omanyte"
OMASTAR = "Omastar"
KABUTO = "Kabuto"
KABUTOPS = "Kabutops"
AERODACTYL = "Aerodactyl"
SNORLAX = "Snorlax"
ARTICUNO = "Articuno"
ZAPDOS = "Zapdos"
MOLTRES = "Moltres"
DRATINI = "Dratini"
DRAGONAIR = "Dragonair"
DRAGONITE = "Dragonite"
MEWTWO = "Mewtwo"
MEW = "Mew"
CHIKORITA = "Chikorita"
BAYLEEF = "Bayleef"
MEGANIUM = "Meganium"
CYNDAQUIL = "Cyndaquil"
QUILAVA = "Quilava"
TYPHLOSION = "Typhlosion"
TOTODILE = "Totodile"
CROCONAW = "Croconaw"
FERALIGATR = "Feraligatr"
SENTRET = "Sentret"
FURRET = "Furret"
HOOTHOOT = "Hoothoot"
NOCTOWL = "Noctowl"
LEDYBA = "Ledyba"
LEDIAN = "Ledian"
SPINARAK = "Spinarak"
ARIADOS = "Ariados"
CROBAT = "Crobat"
CHINCHOU = "Chinchou"
LANTURN = "Lanturn"
PICHU = "Pichu"
CLEFFA = "Cleffa"
IGGLYBUFF = "Igglybuff"
TOGEPI = "Togepi"
TOGETIC = "Togetic"
NATU = "Natu"
XATU = "Xatu"
MAREEP = "Mareep"
FLAAFFY = "Flaaffy"
AMPHAROS = "Ampharos"
BELLOSSOM = "Bellossom"
MARILL = "Marill"
AZUMARILL = "Azumarill"
SUDOWOODO = "Sudowoodo"
POLITOED = "Politoed"
HOPPIP = "Hoppip"
SKIPLOOM = "Skiploom"
JUMPLUFF = "Jumpluff"
AIPOM = "Aipom"
SUNKERN = "Sunkern"
SUNFLORA = "Sunflora"
YANMA = "Yanma"
WOOPER = "Wooper"
QUAGSIRE = "Quagsire"
ESPEON = "Espeon"
UMBREON = "Umbreon"
MURKROW = "Murkrow"
SLOWKING = "Slowking"
MISDREAVUS = "Misdreavus"
UNOWN = "Unown"
WOBBUFFET = "Wobbuffet"
GIRAFARIG = "Girafarig"
PINECO = "Pineco"
FORRETRESS = "Forretress"
DUNSPARCE = "Dunsparce"
GLIGAR = "Gligar"
STEELIX = "Steelix"
SNUBBULL = "Snubbull"
GRANBULL = "Granbull"
QWILFISH = "Qwilfish"
SCIZOR = "Scizor"
SHUCKLE = "Shuckle"
HERACROSS = "Heracross"
SNEASEL = "Sneasel"
TEDDIURSA = "Teddiursa"
URSARING = "Ursaring"
SLUGMA = "Slugma"
MAGCARGO = "Magcargo"
SWINUB = "Swinub"
PILOSWINE = "Piloswine"
CORSOLA = "Corsola"
REMORAID = "Remoraid"
OCTILLERY = "Octillery"
DELIBIRD = "Delibird"
MANTINE = "Mantine"
SKARMORY = "Skarmory"
HOUNDOUR = "Houndour"
HOUNDOOM = "Houndoom"
KINGDRA = "Kingdra"
PHANPY = "Phanpy"
DONPHAN = "Donphan"
PORYGON2 = "Porygon2"
STANTLER = "Stantler"
SMEARGLE = "Smeargle"
TYROGUE = "Tyrogue"
HITMONTOP = "Hitmontop"
SMOOCHUM = "Smoochum"
ELEKID = "Elekid"
MAGBY = "Magby"
MILTANK = "Miltank"
BLISSEY = "Blissey"
RAIKOU = "Raikou"
ENTEI = "Entei"
SUICUNE = "Suicune"
LARVITAR = "Larvitar"
PUPITAR = "Pupitar"
TYRANITAR = "Tyranitar"
LUGIA = "Lugia"
HO_OH = "Ho-Oh"
CELEBI = "Celebi"
TREECKO = "Treecko"
GROVYLE = "Grovyle"
SCEPTILE = "Sceptile"
TORCHIC = "Torchic"
COMBUSKEN = "Combusken"
BLAZIKEN = "Blaziken"
MUDKIP = "Mudkip"
MARSHTOMP = "Marshtomp"
SWAMPERT = "Swampert"
POOCHYENA = "Poochyena"
MIGHTYENA = "Mightyena"
ZIGZAGOON = "Zigzagoon"
LINOONE = "Linoone"
WURMPLE = "Wurmple"
SILCOON = "Silcoon"
BEAUTIFLY = "Beautifly"
CASCOON = "Cascoon"
DUSTOX = "Dustox"
LOTAD = "Lotad"
LOMBRE = "Lombre"
LUDICOLO = "Ludicolo"
SEEDOT = "Seedot"
NUZLEAF = "Nuzleaf"
SHIFTRY = "Shiftry"
TAILLOW = "Taillow"
SWELLOW = "Swellow"
WINGULL = "Wingull"
PELIPPER = "Pelipper"
RALTS = "Ralts"
KIRLIA = "Kirlia"
GARDEVOIR = "Gardevoir"
SURSKIT = "Surskit"
MASQUERAIN = "Masquerain"
SHROOMISH = "Shroomish"
BRELOOM = "Breloom"
SLAKOTH = "Slakoth"
VIGOROTH = "Vigoroth"
SLAKING = "Slaking"
NINCADA = "Nincada"
NINJASK = "Ninjask"
SHEDINJA = "Shedinja"
WHISMUR = "Whismur"
LOUDRED = "Loudred"
EXPLOUD = "Exploud"
MAKUHITA = "Makuhita"
HARIYAMA = "Hariyama"
AZURILL = "Azurill"
NOSEPASS = "Nosepass"
SKITTY = "Skitty"
DELCATTY = "Delcatty"
SABLEYE = "Sableye"
MAWILE = "Mawile"
ARON = "Aron"
LAIRON = "Lairon"
AGGRON = "Aggron"
MEDITITE = "Meditite"
MEDICHAM = "Medicham"
ELECTRIKE = "Electrike"
MANECTRIC = "Manectric"
PLUSLE = "Plusle"
MINUN = "Minun"
VOLBEAT = "Volbeat"
ILLUMISE = "Illumise"
ROSELIA = "Roselia"
GULPIN = "Gulpin"
SWALOT = "Swalot"
CARVANHA = "Carvanha"
SHARPEDO = "Sharpedo"
WAILMER = "Wailmer"
WAILORD = "Wailord"
NUMEL = "Numel"
CAMERUPT = "Camerupt"
TORKOAL = "Torkoal"
SPOINK = "Spoink"
GRUMPIG = "Grumpig"
SPINDA = "Spinda"
TRAPINCH = "Trapinch"
VIBRAVA = "Vibrava"
FLYGON = "Flygon"
CACNEA = "Cacnea"
CACTURNE = "Cacturne"
SWABLU = "Swablu"
ALTARIA = "Altaria"
ZANGOOSE = "Zangoose"
SEVIPER = "Seviper"
LUNATONE = "Lunatone"
SOLROCK = "Solrock"
BARBOACH = "Barboach"
WHISCASH = "Whiscash"
CORPHISH = "Corphish"
CRAWDAUNT = "Crawdaunt"
BALTOY = "Baltoy"
CLAYDOL = "Claydol"
LILEEP = "Lileep"
CRADILY = "Cradily"
ANORITH = "Anorith"
ARMALDO = "Armaldo"
FEEBAS = "Feebas"
MILOTIC = "Milotic"
CASTFORM = "Castform"
KECLEON = "Kecleon"
SHUPPET = "Shuppet"
BANETTE = "Banette"
DUSKULL = "Duskull"
DUSCLOPS = "Dusclops"
TROPIUS = "Tropius"
CHIMECHO = "Chimecho"
ABSOL = "Absol"
WYNAUT = "Wynaut"
SNORUNT = "Snorunt"
GLALIE = "Glalie"
SPHEAL = "Spheal"
SEALEO = "Sealeo"
WALREIN = "Walrein"
CLAMPERL = "Clamperl"
HUNTAIL = "Huntail"
GOREBYSS = "Gorebyss"
RELICANTH = "Relicanth"
LUVDISC = "Luvdisc"
BAGON = "Bagon"
SHELGON = "Shelgon"
SALAMENCE = "Salamence"
BELDUM = "Beldum"
METANG = "Metang"
METAGROSS = "Metagross"
REGIROCK = "Regirock"
REGICE = "Regice"
REGISTEEL = "Registeel"
LATIAS = "Latias"
LATIOS = "Latios"
KYOGRE = "Kyogre"
GROUDON = "Groudon"
RAYQUAZA = "Rayquaza"
JIRACHI = "Jirachi"
DEOXYS = "Deoxys"
TURTWIG = "Turtwig"
GROTLE = "Grotle"
TORTERRA = "Torterra"
CHIMCHAR = "Chimchar"
MONFERNO = "Monferno"
INFERNAPE = "Infernape"
PIPLUP = "Piplup"
PRINPLUP = "Prinplup"
EMPOLEON = "Empoleon"
STARLY = "Starly"
STARAVIA = "Staravia"
STARAPTOR = "Staraptor"
BIDOOF = "Bidoof"
BIBAREL = "Bibarel"
KRICKETOT = "Kricketot"
KRICKETUNE = "Kricketune"
SHINX = "Shinx"
LUXIO = "Luxio"
LUXRAY = "Luxray"
BUDEW = "Budew"
ROSERADE = "Roserade"
CRANIDOS = "Cranidos"
RAMPARDOS = "Rampardos"
SHIELDON = "Shieldon"
BASTIODON = "Bastiodon"
BURMY = "Burmy"
WORMADAM = "Wormadam"
MOTHIM = "Mothim"
COMBEE = "Combee"
VESPIQUEN = "Vespiquen"
PACHIRISU = "Pachirisu"
BUIZEL = "Buizel"
FLOATZEL = "Floatzel"
CHERUBI = "Cherubi"
CHERRIM = "Cherrim"
SHELLOS = "Shellos"
GASTRODON = "Gastrodon"
AMBIPOM = "Ambipom"
DRIFLOON = "Drifloon"
DRIFBLIM = "Drifblim"
BUNEARY = "Buneary"
LOPUNNY = "Lopunny"
MISMAGIUS = "Mismagius"
HONCHKROW = "Honchkrow"
GLAMEOW = "Glameow"
PURUGLY = "Purugly"
CHINGLING = "Chingling"
STUNKY = "Stunky"
SKUNTANK = "Skuntank"
BRONZOR = "Bronzor"
BRONZONG = "Bronzong"
BONSLY = "Bonsly"
MIMEJR = "Mime Jr."
HAPPINY = "Happiny"
CHATOT = "Chatot"
SPIRITOMB = "Spiritomb"
GIBLE = "Gible"
GABITE = "Gabite"
GARCHOMP = "Garchomp"
MUNCHLAX = "Munchlax"
RIOLU = "Riolu"
LUCARIO = "Lucario"
HIPPOPOTAS = "Hippopotas"
HIPPOWDON = "Hippowdon"
SKORUPI = "Skorupi"
DRAPION = "Drapion"
CROAGUNK = "Croagunk"
TOXICROAK = "Toxicroak"
CARNIVINE = "Carnivine"
FINNEON = "Finneon"
LUMINEON = "Lumineon"
MANTYKE = "Mantyke"
SNOVER = "Snover"
ABOMASNOW = "Abomasnow"
WEAVILE = "Weavile"
MAGNEZONE = "Magnezone"
LICKILICKY = "Lickilicky"
RHYPERIOR = "Rhyperior"
TANGROWTH = "Tangrowth"
ELECTIVIRE = "Electivire"
MAGMORTAR = "Magmortar"
TOGEKISS = "Togekiss"
YANMEGA = "Yanmega"
LEAFEON = "Leafeon"
GLACEON = "Glaceon"
GLISCOR = "Gliscor"
MAMOSWINE = "Mamoswine"
PORYGON_Z = "Porygon-Z"
GALLADE = "Gallade"
PROBOPASS = "Probopass"
DUSKNOIR = "Dusknoir"
FROSLASS = "Froslass"
ROTOM = "Rotom"
UXIE = "Uxie"
MESPRIT = "Mesprit"
AZELF = "Azelf"
DIALGA = "Dialga"
PALKIA = "Palkia"
HEATRAN = "Heatran"
REGIGIGAS = "Regigigas"
GIRATINA = "Giratina"
CRESSELIA = "Cresselia"
PHIONE = "Phione"
MANAPHY = "Manaphy"
DARKRAI = "Darkrai"
SHAYMIN = "Shaymin"
ARCEUS = "Arceus"
VICTINI = "Victini"
SNIVY = "Snivy"
SERVINE = "Servine"
SERPERIOR = "Serperior"
TEPIG = "Tepig"
PIGNITE = "Pignite"
EMBOAR = "Emboar"
OSHAWOTT = "Oshawott"
DEWOTT = "Dewott"
SAMUROTT = "Samurott"
PATRAT = "Patrat"
WATCHOG = "Watchog"
LILLIPUP = "Lillipup"
HERDIER = "Herdier"
STOUTLAND = "Stoutland"
PURRLOIN = "Purrloin"
LIEPARD = "Liepard"
PANSAGE = "Pansage"
SIMISAGE = "Simisage"
PANSEAR = "Pansear"
SIMISEAR = "Simisear"
PANPOUR = "Panpour"
SIMIPOUR = "Simipour"
MUNNA = "Munna"
MUSHARNA = "Musharna"
PIDOVE = "Pidove"
TRANQUILL = "Tranquill"
UNFEZANT = "Unfezant"
BLITZLE = "Blitzle"
ZEBSTRIKA = "Zebstrika"
ROGGENROLA = "Roggenrola"
BOLDORE = "Boldore"
GIGALITH = "Gigalith"
WOOBAT = "Woobat"
SWOOBAT = "Swoobat"
DRILBUR = "Drilbur"
EXCADRILL = "Excadrill"
AUDINO = "Audino"
TIMBURR = "Timburr"
GURDURR = "Gurdurr"
CONKELDURR = "Conkeldurr"
TYMPOLE = "Tympole"
PALPITOAD = "Palpitoad"
SEISMITOAD = "Seismitoad"
THROH = "Throh"
SAWK = "Sawk"
SEWADDLE = "Sewaddle"
SWADLOON = "Swadloon"
LEAVANNY = "Leavanny"
VENIPEDE = "Venipede"
WHIRLIPEDE = "Whirlipede"
SCOLIPEDE = "Scolipede"
COTTONEE = "Cottonee"
WHIMSICOTT = "Whimsicott"
PETILIL = "Petilil"
LILLIGANT = "Lilligant"
BASCULIN = "Basculin"
SANDILE = "Sandile"
KROKOROK = "Krokorok"
KROOKODILE = "Krookodile"
DARUMAKA = "Darumaka"
DARMANITAN = "Darmanitan"
MARACTUS = "Maractus"
DWEBBLE = "Dwebble"
CRUSTLE = "Crustle"
SCRAGGY = "Scraggy"
SCRAFTY = "Scrafty"
SIGILYPH = "Sigilyph"
YAMASK = "Yamask"
COFAGRIGUS = "Cofagrigus"
TIRTOUGA = "Tirtouga"
CARRACOSTA = "Carracosta"
ARCHEN = "Archen"
ARCHEOPS = "Archeops"
TRUBBISH = "Trubbish"
GARBODOR = "Garbodor"
ZORUA = "Zorua"
ZOROARK = "Zoroark"
MINCCINO = "Minccino"
CINCCINO = "Cinccino"
GOTHITA = "Gothita"
GOTHORITA = "Gothorita"
GOTHITELLE = "Gothitelle"
SOLOSIS = "Solosis"
DUOSION = "Duosion"
REUNICLUS = "Reuniclus"
DUCKLETT = "Ducklett"
SWANNA = "Swanna"
VANILLITE = "Vanillite"
VANILLISH = "Vanillish"
VANILLUXE = "Vanilluxe"
DEERLING = "Deerling"
SAWSBUCK = "Sawsbuck"
EMOLGA = "Emolga"
KARRABLAST = "Karrablast"
ESCAVALIER = "Escavalier"
FOONGUS = "Foongus"
AMOONGUSS = "Amoonguss"
FRILLISH = "Frillish"
JELLICENT = "Jellicent"
ALOMOMOLA = "Alomomola"
JOLTIK = "Joltik"
GALVANTULA = "Galvantula"
FERROSEED = "Ferroseed"
FERROTHORN = "Ferrothorn"
KLINK = "Klink"
KLANG = "Klang"
KLINKLANG = "Klinklang"
TYNAMO = "Tynamo"
EELEKTRIK = "Eelektrik"
EELEKTROSS = "Eelektross"
ELGYEM = "Elgyem"
BEHEEYEM = "Beheeyem"
LITWICK = "Litwick"
LAMPENT = "Lampent"
CHANDELURE = "Chandelure"
AXEW = "Axew"
FRAXURE = "Fraxure"
HAXORUS = "Haxorus"
CUBCHOO = "Cubchoo"
BEARTIC = "Beartic"
CRYOGONAL = "Cryogonal"
SHELMET = "Shelmet"
ACCELGOR = "Accelgor"
STUNFISK = "Stunfisk"
MIENFOO = "Mienfoo"
MIENSHAO = "Mienshao"
DRUDDIGON = "Druddigon"
GOLETT = "Golett"
GOLURK = "Golurk"
PAWNIARD = "Pawniard"
BISHARP = "Bisharp"
BOUFFALANT = "Bouffalant"
RUFFLET = "Rufflet"
BRAVIARY = "Braviary"
VULLABY = "Vullaby"
MANDIBUZZ = "Mandibuzz"
HEATMOR = "Heatmor"
DURANT = "Durant"
DEINO = "Deino"
ZWEILOUS = "Zweilous"
HYDREIGON = "Hydreigon"
LARVESTA = "Larvesta"
VOLCARONA = "Volcarona"
COBALION = "Cobalion"
TERRAKION = "Terrakion"
VIRIZION = "Virizion"
TORNADUS = "Tornadus"
THUNDURUS = "Thundurus"
RESHIRAM = "Reshiram"
ZEKROM = "Zekrom"
LANDORUS = "Landorus"
KYUREM = "Kyurem"
KELDEO = "Keldeo"
MELOETTA = "Meloetta"
GENESECT = "Genesect"
CHESPIN = "Chespin"
QUILLADIN = "Quilladin"
CHESNAUGHT = "Chesnaught"
FENNEKIN = "Fennekin"
BRAIXEN = "Braixen"
DELPHOX = "Delphox"
FROAKIE = "Froakie"
FROGADIER = "Frogadier"
GRENINJA = "Greninja"
BUNNELBY = "Bunnelby"
DIGGERSBY = "Diggersby"
FLETCHLING = "Fletchling"
FLETCHINDER = "Fletchinder"
TALONFLAME = "Talonflame"
SCATTERBUG = "Scatterbug"
SPEWPA = "Spewpa"
VIVILLON = "Vivillon"
LITLEO = "Litleo"
PYROAR = "Pyroar"
FLABEBE = "Flabébé"
FLOETTE = "Floette"
FLORGES = "Florges"
SKIDDO = "Skiddo"
GOGOAT = "Gogoat"
PANCHAM = "Pancham"
PANGORO = "Pangoro"
FURFROU = "Furfrou"
ESPURR = "Espurr"
MEOWSTIC = "Meowstic"
HONEDGE = "Honedge"
DOUBLADE = "Doublade"
AEGISLASH = "Aegislash"
SPRITZEE = "Spritzee"
AROMATISSE = "Aromatisse"
SWIRLIX = "Swirlix"
SLURPUFF = "Slurpuff"
INKAY = "Inkay"
MALAMAR = "Malamar"
BINACLE = "Binacle"
BARBARACLE = "Barbaracle"
SKRELP = "Skrelp"
DRAGALGE = "Dragalge"
CLAUNCHER = "Clauncher"
CLAWITZER = "Clawitzer"
HELIOPTILE = "Helioptile"
HELIOLISK = "Heliolisk"
TYRUNT = "Tyrunt"
TYRANTRUM = "Tyrantrum"
AMAURA = "Amaura"
AURORUS = "Aurorus"
SYLVEON = "Sylveon"
HAWLUCHA = "Hawlucha"
DEDENNE = "Dedenne"
CARBINK = "Carbink"
GOOMY = "Goomy"
SLIGGOO = "Sliggoo"
GOODRA = "Goodra"
KLEFKI = "Klefki"
PHANTUMP = "Phantump"
TREVENANT = "Trevenant"
PUMPKABOO = "Pumpkaboo"
GOURGEIST = "Gourgeist"
BERGMITE = "Bergmite"
AVALUGG = "Avalugg"
NOIBAT = "Noibat"
NOIVERN = "Noivern"
XERNEAS = "Xerneas"
YVELTAL = "Yveltal"
ZYGARDE = "Zygarde"
DIANCIE = "Diancie"
HOOPA = "Hoopa"
VOLCANION = "Volcanion"
ROWLET = "Rowlet"
DARTRIX = "Dartrix"
DECIDUEYE = "Decidueye"
LITTEN = "Litten"
TORRACAT = "Torracat"
INCINEROAR = "Incineroar"
POPPLIO = "Popplio"
BRIONNE = "Brionne"
PRIMARINA = "Primarina"
PIKIPEK = "Pikipek"
TRUMBEAK = "Trumbeak"
TOUCANNON = "Toucannon"
YUNGOOS = "Yungoos"
GUMSHOOS = "Gumshoos"
GRUBBIN = "Grubbin"
CHARJABUG = "Charjabug"
VIKAVOLT = "Vikavolt"
CRABRAWLER = "Crabrawler"
CRABOMINABLE = "Crabominable"
ORICORIO = "Oricorio"
CUTIEFLY = "Cutiefly"
RIBOMBEE = "Ribombee"
ROCKRUFF = "Rockruff"
LYCANROC = "Lycanroc"
WISHIWASHI = "Wishiwashi"
MAREANIE = "Mareanie"
TOXAPEX = "Toxapex"
MUDBRAY = "Mudbray"
MUDSDALE = "Mudsdale"
DEWPIDER = "Dewpider"
ARAQUANID = "Araquanid"
FOMANTIS = "Fomantis"
LURANTIS = "Lurantis"
MORELULL = "Morelull"
SHIINOTIC = "Shiinotic"
SALANDIT = "Salandit"
SALAZZLE = "Salazzle"
STUFFUL = "Stufful"
BEWEAR = "Bewear"
BOUNSWEET = "Bounsweet"
STEENEE = "Steenee"
TSAREENA = "Tsareena"
COMFEY = "Comfey"
ORANGURU = "Oranguru"
PASSIMIAN = "Passimian"
WIMPOD = "Wimpod"
GOLISOPOD = "Golisopod"
SANDYGAST = "Sandygast"
PALOSSAND = "Palossand"
PYUKUMUKU = "Pyukumuku"
TYPENULL = "Type: Null"
SILVALLY = "Silvally"
MINIOR = "Minior"
KOMALA = "Komala"
TURTONATOR = "Turtonator"
TOGEDEMARU = "Togedemaru"
MIMIKYU = "Mimikyu"
BRUXISH = "Bruxish"
DRAMPA = "Drampa"
DHELMISE = "Dhelmise"
JANGMO_O = "Jangmo-o"
HAKAMO_O = "Hakamo-o"
KOMMO_O = "Kommo-o"
TAPUKOKO = "Tapu Koko"
TAPULELE = "Tapu Lele"
TAPUBULU = "Tapu Bulu"
TAPUFINI = "Tapu Fini"
COSMOG = "Cosmog"
COSMOEM = "Cosmoem"
SOLGALEO = "Solgaleo"
LUNALA = "Lunala"
NIHILEGO = "Nihilego"
BUZZWOLE = "Buzzwole"
PHEROMOSA = "Pheromosa"
XURKITREE = "Xurkitree"
CELESTEELA = "Celesteela"
KARTANA = "Kartana"
GUZZLORD = "Guzzlord"
NECROZMA = "Necrozma"
MAGEARNA = "Magearna"
MARSHADOW = "Marshadow"
POIPOLE = "Poipole"
NAGANADEL = "Naganadel"
STAKATAKA = "Stakataka"
BLACEPHALON = "Blacephalon"
ZERAORA = "Zeraora"
MELTAN = "Meltan"
MELMETAL = "Melmetal"
GROOKEY = "Grookey"
THWACKEY = "Thwackey"
RILLABOOM = "Rillaboom"
SCORBUNNY = "Scorbunny"
RABOOT = "Raboot"
CINDERACE = "Cinderace"
SOBBLE = "Sobble"
DRIZZILE = "Drizzile"
INTELEON = "Inteleon"
SKWOVET = "Skwovet"
GREEDENT = "Greedent"
ROOKIDEE = "Rookidee"
CORVISQUIRE = "Corvisquire"
CORVIKNIGHT = "Corviknight"
BLIPBUG = "Blipbug"
DOTTLER = "Dottler"
ORBEETLE = "Orbeetle"
NICKIT = "Nickit"
THIEVUL = "Thievul"
GOSSIFLEUR = "Gossifleur"
ELDEGOSS = "Eldegoss"
WOOLOO = "Wooloo"
DUBWOOL = "Dubwool"
CHEWTLE = "Chewtle"
DREDNAW = "Drednaw"
YAMPER = "Yamper"
BOLTUND = "Boltund"
ROLYCOLY = "Rolycoly"
CARKOL = "Carkol"
COALOSSAL = "Coalossal"
APPLIN = "Applin"
FLAPPLE = "Flapple"
APPLETUN = "Appletun"
SILICOBRA = "Silicobra"
SANDACONDA = "Sandaconda"
CRAMORANT = "Cramorant"
ARROKUDA = "Arrokuda"
BARRASKEWDA = "Barraskewda"
TOXEL = "Toxel"
TOXTRICITY = "Toxtricity"
SIZZLIPEDE = "Sizzlipede"
CENTISKORCH = "Centiskorch"
CLOBBOPUS = "Clobbopus"
GRAPPLOCT = "Grapploct"
SINISTEA = "Sinistea"
POLTEAGEIST = "Polteageist"
HATENNA = "Hatenna"
HATTREM = "Hattrem"
HATTERENE = "Hatterene"
IMPIDIMP = "Impidimp"
MORGREM = "Morgrem"
GRIMMSNARL = "Grimmsnarl"
OBSTAGOON = "Obstagoon"
PERRSERKER = "Perrserker"
CURSOLA = "Cursola"
SIRFETCHD = "Sirfetch'd"
MRRIME = "Mr. Rime"
RUNERIGUS = "Runerigus"
MILCERY = "Milcery"
ALCREMIE = "Alcremie"
FALINKS = "Falinks"
PINCURCHIN = "Pincurchin"
SNOM = "Snom"
FROSMOTH = "Frosmoth"
STONJOURNER = "Stonjourner"
EISCUE = "Eiscue"
INDEEDEE = "Indeedee"
MORPEKO = "Morpeko"
CUFANT = "Cufant"
COPPERAJAH = "Copperajah"
DRACOZOLT = "Dracozolt"
ARCTOZOLT = "Arctozolt"
DRACOVISH = "Dracovish"
ARCTOVISH = "Arctovish"
DURALUDON = "Duraludon"
DREEPY = "Dreepy"
DRAKLOAK = "Drakloak"
DRAGAPULT = "Dragapult"
ZACIAN = "Zacian"
ZAMAZENTA = "Zamazenta"
ETERNATUS = "Eternatus"
KUBFU = "Kubfu"
URSHIFU = "Urshifu"
ZARUDE = "Zarude"
REGIELEKI = "Regieleki"
REGIDRAGO = "Regidrago"
GLASTRIER = "Glastrier"
SPECTRIER = "Spectrier"
CALYREX = "Calyrex"

BULBASAUR_SEEN = "Bulbasaur seen"
IVYSAUR_SEEN = "Ivysaur seen"
VENUSAUR_SEEN = "Venusaur seen"
CHARMANDER_SEEN = "Charmander seen"
CHARMELEON_SEEN = "Charmeleon seen"
CHARIZARD_SEEN = "Charizard seen"
SQUIRTLE_SEEN = "Squirtle seen"
WARTORTLE_SEEN = "Wartortle seen"
BLASTOISE_SEEN = "Blastoise seen"
CATERPIE_SEEN = "Caterpie seen"
METAPOD_SEEN = "Metapod seen"
BUTTERFREE_SEEN = "Butterfree seen"
WEEDLE_SEEN = "Weedle seen"
KAKUNA_SEEN = "Kakuna seen"
BEEDRILL_SEEN = "Beedrill seen"
PIDGEY_SEEN = "Pidgey seen"
PIDGEOTTO_SEEN = "Pidgeotto seen"
PIDGEOT_SEEN = "Pidgeot seen"
RATTATA_SEEN = "Rattata seen"
RATICATE_SEEN = "Raticate seen"
SPEAROW_SEEN = "Spearow seen"
FEAROW_SEEN = "Fearow seen"
EKANS_SEEN = "Ekans seen"
ARBOK_SEEN = "Arbok seen"
PIKACHU_SEEN = "Pikachu seen"
RAICHU_SEEN = "Raichu seen"
SANDSHREW_SEEN = "Sandshrew seen"
SANDSLASH_SEEN = "Sandslash seen"
NIDORAN_F_SEEN = "Nidoran♀ seen"
NIDORINA_SEEN = "Nidorina seen"
NIDOQUEEN_SEEN = "Nidoqueen seen"
NIDORAN_M_SEEN = "Nidoran♂ seen"
NIDORINO_SEEN = "Nidorino seen"
NIDOKING_SEEN = "Nidoking seen"
CLEFAIRY_SEEN = "Clefairy seen"
CLEFABLE_SEEN = "Clefable seen"
VULPIX_SEEN = "Vulpix seen"
NINETALES_SEEN = "Ninetales seen"
JIGGLYPUFF_SEEN = "Jigglypuff seen"
WIGGLYTUFF_SEEN = "Wigglytuff seen"
ZUBAT_SEEN = "Zubat seen"
GOLBAT_SEEN = "Golbat seen"
ODDISH_SEEN = "Oddish seen"
GLOOM_SEEN = "Gloom seen"
VILEPLUME_SEEN = "Vileplume seen"
PARAS_SEEN = "Paras seen"
PARASECT_SEEN = "Parasect seen"
VENONAT_SEEN = "Venonat seen"
VENOMOTH_SEEN = "Venomoth seen"
DIGLETT_SEEN = "Diglett seen"
DUGTRIO_SEEN = "Dugtrio seen"
MEOWTH_SEEN = "Meowth seen"
PERSIAN_SEEN = "Persian seen"
PSYDUCK_SEEN = "Psyduck seen"
GOLDUCK_SEEN = "Golduck seen"
MANKEY_SEEN = "Mankey seen"
PRIMEAPE_SEEN = "Primeape seen"
GROWLITHE_SEEN = "Growlithe seen"
ARCANINE_SEEN = "Arcanine seen"
POLIWAG_SEEN = "Poliwag seen"
POLIWHIRL_SEEN = "Poliwhirl seen"
POLIWRATH_SEEN = "Poliwrath seen"
ABRA_SEEN = "Abra seen"
KADABRA_SEEN = "Kadabra seen"
ALAKAZAM_SEEN = "Alakazam seen"
MACHOP_SEEN = "Machop seen"
MACHOKE_SEEN = "Machoke seen"
MACHAMP_SEEN = "Machamp seen"
BELLSPROUT_SEEN = "Bellsprout seen"
WEEPINBELL_SEEN = "Weepinbell seen"
VICTREEBEL_SEEN = "Victreebel seen"
TENTACOOL_SEEN = "Tentacool seen"
TENTACRUEL_SEEN = "Tentacruel seen"
GEODUDE_SEEN = "Geodude seen"
GRAVELER_SEEN = "Graveler seen"
GOLEM_SEEN = "Golem seen"
PONYTA_SEEN = "Ponyta seen"
RAPIDASH_SEEN = "Rapidash seen"
SLOWPOKE_SEEN = "Slowpoke seen"
SLOWBRO_SEEN = "Slowbro seen"
MAGNEMITE_SEEN = "Magnemite seen"
MAGNETON_SEEN = "Magneton seen"
FARFETCHD_SEEN = "Farfetch'd seen"
DODUO_SEEN = "Doduo seen"
DODRIO_SEEN = "Dodrio seen"
SEEL_SEEN = "Seel seen"
DEWGONG_SEEN = "Dewgong seen"
GRIMER_SEEN = "Grimer seen"
MUK_SEEN = "Muk seen"
SHELLDER_SEEN = "Shellder seen"
CLOYSTER_SEEN = "Cloyster seen"
GASTLY_SEEN = "Gastly seen"
HAUNTER_SEEN = "Haunter seen"
GENGAR_SEEN = "Gengar seen"
ONIX_SEEN = "Onix seen"
DROWZEE_SEEN = "Drowzee seen"
HYPNO_SEEN = "Hypno seen"
KRABBY_SEEN = "Krabby seen"
KINGLER_SEEN = "Kingler seen"
VOLTORB_SEEN = "Voltorb seen"
ELECTRODE_SEEN = "Electrode seen"
EXEGGCUTE_SEEN = "Exeggcute seen"
EXEGGUTOR_SEEN = "Exeggutor seen"
CUBONE_SEEN = "Cubone seen"
MAROWAK_SEEN = "Marowak seen"
HITMONLEE_SEEN = "Hitmonlee seen"
HITMONCHAN_SEEN = "Hitmonchan seen"
LICKITUNG_SEEN = "Lickitung seen"
KOFFING_SEEN = "Koffing seen"
WEEZING_SEEN = "Weezing seen"
RHYHORN_SEEN = "Rhyhorn seen"
RHYDON_SEEN = "Rhydon seen"
CHANSEY_SEEN = "Chansey seen"
TANGELA_SEEN = "Tangela seen"
KANGASKHAN_SEEN = "Kangaskhan seen"
HORSEA_SEEN = "Horsea seen"
SEADRA_SEEN = "Seadra seen"
GOLDEEN_SEEN = "Goldeen seen"
SEAKING_SEEN = "Seaking seen"
STARYU_SEEN = "Staryu seen"
STARMIE_SEEN = "Starmie seen"
MRMIME_SEEN = "Mr. Mime seen"
SCYTHER_SEEN = "Scyther seen"
JYNX_SEEN = "Jynx seen"
ELECTABUZZ_SEEN = "Electabuzz seen"
MAGMAR_SEEN = "Magmar seen"
PINSIR_SEEN = "Pinsir seen"
TAUROS_SEEN = "Tauros seen"
MAGIKARP_SEEN = "Magikarp seen"
GYARADOS_SEEN = "Gyarados seen"
LAPRAS_SEEN = "Lapras seen"
DITTO_SEEN = "Ditto seen"
EEVEE_SEEN = "Eevee seen"
VAPOREON_SEEN = "Vaporeon seen"
JOLTEON_SEEN = "Jolteon seen"
FLAREON_SEEN = "Flareon seen"
PORYGON_SEEN = "Porygon seen"
OMANYTE_SEEN = "Omanyte seen"
OMASTAR_SEEN = "Omastar seen"
KABUTO_SEEN = "Kabuto seen"
KABUTOPS_SEEN = "Kabutops seen"
AERODACTYL_SEEN = "Aerodactyl seen"
SNORLAX_SEEN = "Snorlax seen"
ARTICUNO_SEEN = "Articuno seen"
ZAPDOS_SEEN = "Zapdos seen"
MOLTRES_SEEN = "Moltres seen"
DRATINI_SEEN = "Dratini seen"
DRAGONAIR_SEEN = "Dragonair seen"
DRAGONITE_SEEN = "Dragonite seen"
MEWTWO_SEEN = "Mewtwo seen"
MEW_SEEN = "Mew seen"
CHIKORITA_SEEN = "Chikorita seen"
BAYLEEF_SEEN = "Bayleef seen"
MEGANIUM_SEEN = "Meganium seen"
CYNDAQUIL_SEEN = "Cyndaquil seen"
QUILAVA_SEEN = "Quilava seen"
TYPHLOSION_SEEN = "Typhlosion seen"
TOTODILE_SEEN = "Totodile seen"
CROCONAW_SEEN = "Croconaw seen"
FERALIGATR_SEEN = "Feraligatr seen"
SENTRET_SEEN = "Sentret seen"
FURRET_SEEN = "Furret seen"
HOOTHOOT_SEEN = "Hoothoot seen"
NOCTOWL_SEEN = "Noctowl seen"
LEDYBA_SEEN = "Ledyba seen"
LEDIAN_SEEN = "Ledian seen"
SPINARAK_SEEN = "Spinarak seen"
ARIADOS_SEEN = "Ariados seen"
CROBAT_SEEN = "Crobat seen"
CHINCHOU_SEEN = "Chinchou seen"
LANTURN_SEEN = "Lanturn seen"
PICHU_SEEN = "Pichu seen"
CLEFFA_SEEN = "Cleffa seen"
IGGLYBUFF_SEEN = "Igglybuff seen"
TOGEPI_SEEN = "Togepi seen"
TOGETIC_SEEN = "Togetic seen"
NATU_SEEN = "Natu seen"
XATU_SEEN = "Xatu seen"
MAREEP_SEEN = "Mareep seen"
FLAAFFY_SEEN = "Flaaffy seen"
AMPHAROS_SEEN = "Ampharos seen"
BELLOSSOM_SEEN = "Bellossom seen"
MARILL_SEEN = "Marill seen"
AZUMARILL_SEEN = "Azumarill seen"
SUDOWOODO_SEEN = "Sudowoodo seen"
POLITOED_SEEN = "Politoed seen"
HOPPIP_SEEN = "Hoppip seen"
SKIPLOOM_SEEN = "Skiploom seen"
JUMPLUFF_SEEN = "Jumpluff seen"
AIPOM_SEEN = "Aipom seen"
SUNKERN_SEEN = "Sunkern seen"
SUNFLORA_SEEN = "Sunflora seen"
YANMA_SEEN = "Yanma seen"
WOOPER_SEEN = "Wooper seen"
QUAGSIRE_SEEN = "Quagsire seen"
ESPEON_SEEN = "Espeon seen"
UMBREON_SEEN = "Umbreon seen"
MURKROW_SEEN = "Murkrow seen"
SLOWKING_SEEN = "Slowking seen"
MISDREAVUS_SEEN = "Misdreavus seen"
UNOWN_SEEN = "Unown seen"
WOBBUFFET_SEEN = "Wobbuffet seen"
GIRAFARIG_SEEN = "Girafarig seen"
PINECO_SEEN = "Pineco seen"
FORRETRESS_SEEN = "Forretress seen"
DUNSPARCE_SEEN = "Dunsparce seen"
GLIGAR_SEEN = "Gligar seen"
STEELIX_SEEN = "Steelix seen"
SNUBBULL_SEEN = "Snubbull seen"
GRANBULL_SEEN = "Granbull seen"
QWILFISH_SEEN = "Qwilfish seen"
SCIZOR_SEEN = "Scizor seen"
SHUCKLE_SEEN = "Shuckle seen"
HERACROSS_SEEN = "Heracross seen"
SNEASEL_SEEN = "Sneasel seen"
TEDDIURSA_SEEN = "Teddiursa seen"
URSARING_SEEN = "Ursaring seen"
SLUGMA_SEEN = "Slugma seen"
MAGCARGO_SEEN = "Magcargo seen"
SWINUB_SEEN = "Swinub seen"
PILOSWINE_SEEN = "Piloswine seen"
CORSOLA_SEEN = "Corsola seen"
REMORAID_SEEN = "Remoraid seen"
OCTILLERY_SEEN = "Octillery seen"
DELIBIRD_SEEN = "Delibird seen"
MANTINE_SEEN = "Mantine seen"
SKARMORY_SEEN = "Skarmory seen"
HOUNDOUR_SEEN = "Houndour seen"
HOUNDOOM_SEEN = "Houndoom seen"
KINGDRA_SEEN = "Kingdra seen"
PHANPY_SEEN = "Phanpy seen"
DONPHAN_SEEN = "Donphan seen"
PORYGON2_SEEN = "Porygon2 seen"
STANTLER_SEEN = "Stantler seen"
SMEARGLE_SEEN = "Smeargle seen"
TYROGUE_SEEN = "Tyrogue seen"
HITMONTOP_SEEN = "Hitmontop seen"
SMOOCHUM_SEEN = "Smoochum seen"
ELEKID_SEEN = "Elekid seen"
MAGBY_SEEN = "Magby seen"
MILTANK_SEEN = "Miltank seen"
BLISSEY_SEEN = "Blissey seen"
RAIKOU_SEEN = "Raikou seen"
ENTEI_SEEN = "Entei seen"
SUICUNE_SEEN = "Suicune seen"
LARVITAR_SEEN = "Larvitar seen"
PUPITAR_SEEN = "Pupitar seen"
TYRANITAR_SEEN = "Tyranitar seen"
LUGIA_SEEN = "Lugia seen"
HO_OH_SEEN = "Ho-Oh seen"
CELEBI_SEEN = "Celebi seen"
TREECKO_SEEN = "Treecko seen"
GROVYLE_SEEN = "Grovyle seen"
SCEPTILE_SEEN = "Sceptile seen"
TORCHIC_SEEN = "Torchic seen"
COMBUSKEN_SEEN = "Combusken seen"
BLAZIKEN_SEEN = "Blaziken seen"
MUDKIP_SEEN = "Mudkip seen"
MARSHTOMP_SEEN = "Marshtomp seen"
SWAMPERT_SEEN = "Swampert seen"
POOCHYENA_SEEN = "Poochyena seen"
MIGHTYENA_SEEN = "Mightyena seen"
ZIGZAGOON_SEEN = "Zigzagoon seen"
LINOONE_SEEN = "Linoone seen"
WURMPLE_SEEN = "Wurmple seen"
SILCOON_SEEN = "Silcoon seen"
BEAUTIFLY_SEEN = "Beautifly seen"
CASCOON_SEEN = "Cascoon seen"
DUSTOX_SEEN = "Dustox seen"
LOTAD_SEEN = "Lotad seen"
LOMBRE_SEEN = "Lombre seen"
LUDICOLO_SEEN = "Ludicolo seen"
SEEDOT_SEEN = "Seedot seen"
NUZLEAF_SEEN = "Nuzleaf seen"
SHIFTRY_SEEN = "Shiftry seen"
TAILLOW_SEEN = "Taillow seen"
SWELLOW_SEEN = "Swellow seen"
WINGULL_SEEN = "Wingull seen"
PELIPPER_SEEN = "Pelipper seen"
RALTS_SEEN = "Ralts seen"
KIRLIA_SEEN = "Kirlia seen"
GARDEVOIR_SEEN = "Gardevoir seen"
SURSKIT_SEEN = "Surskit seen"
MASQUERAIN_SEEN = "Masquerain seen"
SHROOMISH_SEEN = "Shroomish seen"
BRELOOM_SEEN = "Breloom seen"
SLAKOTH_SEEN = "Slakoth seen"
VIGOROTH_SEEN = "Vigoroth seen"
SLAKING_SEEN = "Slaking seen"
NINCADA_SEEN = "Nincada seen"
NINJASK_SEEN = "Ninjask seen"
SHEDINJA_SEEN = "Shedinja seen"
WHISMUR_SEEN = "Whismur seen"
LOUDRED_SEEN = "Loudred seen"
EXPLOUD_SEEN = "Exploud seen"
MAKUHITA_SEEN = "Makuhita seen"
HARIYAMA_SEEN = "Hariyama seen"
AZURILL_SEEN = "Azurill seen"
NOSEPASS_SEEN = "Nosepass seen"
SKITTY_SEEN = "Skitty seen"
DELCATTY_SEEN = "Delcatty seen"
SABLEYE_SEEN = "Sableye seen"
MAWILE_SEEN = "Mawile seen"
ARON_SEEN = "Aron seen"
LAIRON_SEEN = "Lairon seen"
AGGRON_SEEN = "Aggron seen"
MEDITITE_SEEN = "Meditite seen"
MEDICHAM_SEEN = "Medicham seen"
ELECTRIKE_SEEN = "Electrike seen"
MANECTRIC_SEEN = "Manectric seen"
PLUSLE_SEEN = "Plusle seen"
MINUN_SEEN = "Minun seen"
VOLBEAT_SEEN = "Volbeat seen"
ILLUMISE_SEEN = "Illumise seen"
ROSELIA_SEEN = "Roselia seen"
GULPIN_SEEN = "Gulpin seen"
SWALOT_SEEN = "Swalot seen"
CARVANHA_SEEN = "Carvanha seen"
SHARPEDO_SEEN = "Sharpedo seen"
WAILMER_SEEN = "Wailmer seen"
WAILORD_SEEN = "Wailord seen"
NUMEL_SEEN = "Numel seen"
CAMERUPT_SEEN = "Camerupt seen"
TORKOAL_SEEN = "Torkoal seen"
SPOINK_SEEN = "Spoink seen"
GRUMPIG_SEEN = "Grumpig seen"
SPINDA_SEEN = "Spinda seen"
TRAPINCH_SEEN = "Trapinch seen"
VIBRAVA_SEEN = "Vibrava seen"
FLYGON_SEEN = "Flygon seen"
CACNEA_SEEN = "Cacnea seen"
CACTURNE_SEEN = "Cacturne seen"
SWABLU_SEEN = "Swablu seen"
ALTARIA_SEEN = "Altaria seen"
ZANGOOSE_SEEN = "Zangoose seen"
SEVIPER_SEEN = "Seviper seen"
LUNATONE_SEEN = "Lunatone seen"
SOLROCK_SEEN = "Solrock seen"
BARBOACH_SEEN = "Barboach seen"
WHISCASH_SEEN = "Whiscash seen"
CORPHISH_SEEN = "Corphish seen"
CRAWDAUNT_SEEN = "Crawdaunt seen"
BALTOY_SEEN = "Baltoy seen"
CLAYDOL_SEEN = "Claydol seen"
LILEEP_SEEN = "Lileep seen"
CRADILY_SEEN = "Cradily seen"
ANORITH_SEEN = "Anorith seen"
ARMALDO_SEEN = "Armaldo seen"
FEEBAS_SEEN = "Feebas seen"
MILOTIC_SEEN = "Milotic seen"
CASTFORM_SEEN = "Castform seen"
KECLEON_SEEN = "Kecleon seen"
SHUPPET_SEEN = "Shuppet seen"
BANETTE_SEEN = "Banette seen"
DUSKULL_SEEN = "Duskull seen"
DUSCLOPS_SEEN = "Dusclops seen"
TROPIUS_SEEN = "Tropius seen"
CHIMECHO_SEEN = "Chimecho seen"
ABSOL_SEEN = "Absol seen"
WYNAUT_SEEN = "Wynaut seen"
SNORUNT_SEEN = "Snorunt seen"
GLALIE_SEEN = "Glalie seen"
SPHEAL_SEEN = "Spheal seen"
SEALEO_SEEN = "Sealeo seen"
WALREIN_SEEN = "Walrein seen"
CLAMPERL_SEEN = "Clamperl seen"
HUNTAIL_SEEN = "Huntail seen"
GOREBYSS_SEEN = "Gorebyss seen"
RELICANTH_SEEN = "Relicanth seen"
LUVDISC_SEEN = "Luvdisc seen"
BAGON_SEEN = "Bagon seen"
SHELGON_SEEN = "Shelgon seen"
SALAMENCE_SEEN = "Salamence seen"
BELDUM_SEEN = "Beldum seen"
METANG_SEEN = "Metang seen"
METAGROSS_SEEN = "Metagross seen"
REGIROCK_SEEN = "Regirock seen"
REGICE_SEEN = "Regice seen"
REGISTEEL_SEEN = "Registeel seen"
LATIAS_SEEN = "Latias seen"
LATIOS_SEEN = "Latios seen"
KYOGRE_SEEN = "Kyogre seen"
GROUDON_SEEN = "Groudon seen"
RAYQUAZA_SEEN = "Rayquaza seen"
JIRACHI_SEEN = "Jirachi seen"
DEOXYS_SEEN = "Deoxys seen"
TURTWIG_SEEN = "Turtwig seen"
GROTLE_SEEN = "Grotle seen"
TORTERRA_SEEN = "Torterra seen"
CHIMCHAR_SEEN = "Chimchar seen"
MONFERNO_SEEN = "Monferno seen"
INFERNAPE_SEEN = "Infernape seen"
PIPLUP_SEEN = "Piplup seen"
PRINPLUP_SEEN = "Prinplup seen"
EMPOLEON_SEEN = "Empoleon seen"
STARLY_SEEN = "Starly seen"
STARAVIA_SEEN = "Staravia seen"
STARAPTOR_SEEN = "Staraptor seen"
BIDOOF_SEEN = "Bidoof seen"
BIBAREL_SEEN = "Bibarel seen"
KRICKETOT_SEEN = "Kricketot seen"
KRICKETUNE_SEEN = "Kricketune seen"
SHINX_SEEN = "Shinx seen"
LUXIO_SEEN = "Luxio seen"
LUXRAY_SEEN = "Luxray seen"
BUDEW_SEEN = "Budew seen"
ROSERADE_SEEN = "Roserade seen"
CRANIDOS_SEEN = "Cranidos seen"
RAMPARDOS_SEEN = "Rampardos seen"
SHIELDON_SEEN = "Shieldon seen"
BASTIODON_SEEN = "Bastiodon seen"
BURMY_SEEN = "Burmy seen"
WORMADAM_SEEN = "Wormadam seen"
MOTHIM_SEEN = "Mothim seen"
COMBEE_SEEN = "Combee seen"
VESPIQUEN_SEEN = "Vespiquen seen"
PACHIRISU_SEEN = "Pachirisu seen"
BUIZEL_SEEN = "Buizel seen"
FLOATZEL_SEEN = "Floatzel seen"
CHERUBI_SEEN = "Cherubi seen"
CHERRIM_SEEN = "Cherrim seen"
SHELLOS_SEEN = "Shellos seen"
GASTRODON_SEEN = "Gastrodon seen"
AMBIPOM_SEEN = "Ambipom seen"
DRIFLOON_SEEN = "Drifloon seen"
DRIFBLIM_SEEN = "Drifblim seen"
BUNEARY_SEEN = "Buneary seen"
LOPUNNY_SEEN = "Lopunny seen"
MISMAGIUS_SEEN = "Mismagius seen"
HONCHKROW_SEEN = "Honchkrow seen"
GLAMEOW_SEEN = "Glameow seen"
PURUGLY_SEEN = "Purugly seen"
CHINGLING_SEEN = "Chingling seen"
STUNKY_SEEN = "Stunky seen"
SKUNTANK_SEEN = "Skuntank seen"
BRONZOR_SEEN = "Bronzor seen"
BRONZONG_SEEN = "Bronzong seen"
BONSLY_SEEN = "Bonsly seen"
MIMEJR_SEEN = "Mime Jr. seen"
HAPPINY_SEEN = "Happiny seen"
CHATOT_SEEN = "Chatot seen"
SPIRITOMB_SEEN = "Spiritomb seen"
GIBLE_SEEN = "Gible seen"
GABITE_SEEN = "Gabite seen"
GARCHOMP_SEEN = "Garchomp seen"
MUNCHLAX_SEEN = "Munchlax seen"
RIOLU_SEEN = "Riolu seen"
LUCARIO_SEEN = "Lucario seen"
HIPPOPOTAS_SEEN = "Hippopotas seen"
HIPPOWDON_SEEN = "Hippowdon seen"
SKORUPI_SEEN = "Skorupi seen"
DRAPION_SEEN = "Drapion seen"
CROAGUNK_SEEN = "Croagunk seen"
TOXICROAK_SEEN = "Toxicroak seen"
CARNIVINE_SEEN = "Carnivine seen"
FINNEON_SEEN = "Finneon seen"
LUMINEON_SEEN = "Lumineon seen"
MANTYKE_SEEN = "Mantyke seen"
SNOVER_SEEN = "Snover seen"
ABOMASNOW_SEEN = "Abomasnow seen"
WEAVILE_SEEN = "Weavile seen"
MAGNEZONE_SEEN = "Magnezone seen"
LICKILICKY_SEEN = "Lickilicky seen"
RHYPERIOR_SEEN = "Rhyperior seen"
TANGROWTH_SEEN = "Tangrowth seen"
ELECTIVIRE_SEEN = "Electivire seen"
MAGMORTAR_SEEN = "Magmortar seen"
TOGEKISS_SEEN = "Togekiss seen"
YANMEGA_SEEN = "Yanmega seen"
LEAFEON_SEEN = "Leafeon seen"
GLACEON_SEEN = "Glaceon seen"
GLISCOR_SEEN = "Gliscor seen"
MAMOSWINE_SEEN = "Mamoswine seen"
PORYGON_Z_SEEN = "Porygon-Z seen"
GALLADE_SEEN = "Gallade seen"
PROBOPASS_SEEN = "Probopass seen"
DUSKNOIR_SEEN = "Dusknoir seen"
FROSLASS_SEEN = "Froslass seen"
ROTOM_SEEN = "Rotom seen"
UXIE_SEEN = "Uxie seen"
MESPRIT_SEEN = "Mesprit seen"
AZELF_SEEN = "Azelf seen"
DIALGA_SEEN = "Dialga seen"
PALKIA_SEEN = "Palkia seen"
HEATRAN_SEEN = "Heatran seen"
REGIGIGAS_SEEN = "Regigigas seen"
GIRATINA_SEEN = "Giratina seen"
CRESSELIA_SEEN = "Cresselia seen"
PHIONE_SEEN = "Phione seen"
MANAPHY_SEEN = "Manaphy seen"
DARKRAI_SEEN = "Darkrai seen"
SHAYMIN_SEEN = "Shaymin seen"
ARCEUS_SEEN = "Arceus seen"
VICTINI_SEEN = "Victini seen"
SNIVY_SEEN = "Snivy seen"
SERVINE_SEEN = "Servine seen"
SERPERIOR_SEEN = "Serperior seen"
TEPIG_SEEN = "Tepig seen"
PIGNITE_SEEN = "Pignite seen"
EMBOAR_SEEN = "Emboar seen"
OSHAWOTT_SEEN = "Oshawott seen"
DEWOTT_SEEN = "Dewott seen"
SAMUROTT_SEEN = "Samurott seen"
PATRAT_SEEN = "Patrat seen"
WATCHOG_SEEN = "Watchog seen"
LILLIPUP_SEEN = "Lillipup seen"
HERDIER_SEEN = "Herdier seen"
STOUTLAND_SEEN = "Stoutland seen"
PURRLOIN_SEEN = "Purrloin seen"
LIEPARD_SEEN = "Liepard seen"
PANSAGE_SEEN = "Pansage seen"
SIMISAGE_SEEN = "Simisage seen"
PANSEAR_SEEN = "Pansear seen"
SIMISEAR_SEEN = "Simisear seen"
PANPOUR_SEEN = "Panpour seen"
SIMIPOUR_SEEN = "Simipour seen"
MUNNA_SEEN = "Munna seen"
MUSHARNA_SEEN = "Musharna seen"
PIDOVE_SEEN = "Pidove seen"
TRANQUILL_SEEN = "Tranquill seen"
UNFEZANT_SEEN = "Unfezant seen"
BLITZLE_SEEN = "Blitzle seen"
ZEBSTRIKA_SEEN = "Zebstrika seen"
ROGGENROLA_SEEN = "Roggenrola seen"
BOLDORE_SEEN = "Boldore seen"
GIGALITH_SEEN = "Gigalith seen"
WOOBAT_SEEN = "Woobat seen"
SWOOBAT_SEEN = "Swoobat seen"
DRILBUR_SEEN = "Drilbur seen"
EXCADRILL_SEEN = "Excadrill seen"
AUDINO_SEEN = "Audino seen"
TIMBURR_SEEN = "Timburr seen"
GURDURR_SEEN = "Gurdurr seen"
CONKELDURR_SEEN = "Conkeldurr seen"
TYMPOLE_SEEN = "Tympole seen"
PALPITOAD_SEEN = "Palpitoad seen"
SEISMITOAD_SEEN = "Seismitoad seen"
THROH_SEEN = "Throh seen"
SAWK_SEEN = "Sawk seen"
SEWADDLE_SEEN = "Sewaddle seen"
SWADLOON_SEEN = "Swadloon seen"
LEAVANNY_SEEN = "Leavanny seen"
VENIPEDE_SEEN = "Venipede seen"
WHIRLIPEDE_SEEN = "Whirlipede seen"
SCOLIPEDE_SEEN = "Scolipede seen"
COTTONEE_SEEN = "Cottonee seen"
WHIMSICOTT_SEEN = "Whimsicott seen"
PETILIL_SEEN = "Petilil seen"
LILLIGANT_SEEN = "Lilligant seen"
BASCULIN_SEEN = "Basculin seen"
SANDILE_SEEN = "Sandile seen"
KROKOROK_SEEN = "Krokorok seen"
KROOKODILE_SEEN = "Krookodile seen"
DARUMAKA_SEEN = "Darumaka seen"
DARMANITAN_SEEN = "Darmanitan seen"
MARACTUS_SEEN = "Maractus seen"
DWEBBLE_SEEN = "Dwebble seen"
CRUSTLE_SEEN = "Crustle seen"
SCRAGGY_SEEN = "Scraggy seen"
SCRAFTY_SEEN = "Scrafty seen"
SIGILYPH_SEEN = "Sigilyph seen"
YAMASK_SEEN = "Yamask seen"
COFAGRIGUS_SEEN = "Cofagrigus seen"
TIRTOUGA_SEEN = "Tirtouga seen"
CARRACOSTA_SEEN = "Carracosta seen"
ARCHEN_SEEN = "Archen seen"
ARCHEOPS_SEEN = "Archeops seen"
TRUBBISH_SEEN = "Trubbish seen"
GARBODOR_SEEN = "Garbodor seen"
ZORUA_SEEN = "Zorua seen"
ZOROARK_SEEN = "Zoroark seen"
MINCCINO_SEEN = "Minccino seen"
CINCCINO_SEEN = "Cinccino seen"
GOTHITA_SEEN = "Gothita seen"
GOTHORITA_SEEN = "Gothorita seen"
GOTHITELLE_SEEN = "Gothitelle seen"
SOLOSIS_SEEN = "Solosis seen"
DUOSION_SEEN = "Duosion seen"
REUNICLUS_SEEN = "Reuniclus seen"
DUCKLETT_SEEN = "Ducklett seen"
SWANNA_SEEN = "Swanna seen"
VANILLITE_SEEN = "Vanillite seen"
VANILLISH_SEEN = "Vanillish seen"
VANILLUXE_SEEN = "Vanilluxe seen"
DEERLING_SEEN = "Deerling seen"
SAWSBUCK_SEEN = "Sawsbuck seen"
EMOLGA_SEEN = "Emolga seen"
KARRABLAST_SEEN = "Karrablast seen"
ESCAVALIER_SEEN = "Escavalier seen"
FOONGUS_SEEN = "Foongus seen"
AMOONGUSS_SEEN = "Amoonguss seen"
FRILLISH_SEEN = "Frillish seen"
JELLICENT_SEEN = "Jellicent seen"
ALOMOMOLA_SEEN = "Alomomola seen"
JOLTIK_SEEN = "Joltik seen"
GALVANTULA_SEEN = "Galvantula seen"
FERROSEED_SEEN = "Ferroseed seen"
FERROTHORN_SEEN = "Ferrothorn seen"
KLINK_SEEN = "Klink seen"
KLANG_SEEN = "Klang seen"
KLINKLANG_SEEN = "Klinklang seen"
TYNAMO_SEEN = "Tynamo seen"
EELEKTRIK_SEEN = "Eelektrik seen"
EELEKTROSS_SEEN = "Eelektross seen"
ELGYEM_SEEN = "Elgyem seen"
BEHEEYEM_SEEN = "Beheeyem seen"
LITWICK_SEEN = "Litwick seen"
LAMPENT_SEEN = "Lampent seen"
CHANDELURE_SEEN = "Chandelure seen"
AXEW_SEEN = "Axew seen"
FRAXURE_SEEN = "Fraxure seen"
HAXORUS_SEEN = "Haxorus seen"
CUBCHOO_SEEN = "Cubchoo seen"
BEARTIC_SEEN = "Beartic seen"
CRYOGONAL_SEEN = "Cryogonal seen"
SHELMET_SEEN = "Shelmet seen"
ACCELGOR_SEEN = "Accelgor seen"
STUNFISK_SEEN = "Stunfisk seen"
MIENFOO_SEEN = "Mienfoo seen"
MIENSHAO_SEEN = "Mienshao seen"
DRUDDIGON_SEEN = "Druddigon seen"
GOLETT_SEEN = "Golett seen"
GOLURK_SEEN = "Golurk seen"
PAWNIARD_SEEN = "Pawniard seen"
BISHARP_SEEN = "Bisharp seen"
BOUFFALANT_SEEN = "Bouffalant seen"
RUFFLET_SEEN = "Rufflet seen"
BRAVIARY_SEEN = "Braviary seen"
VULLABY_SEEN = "Vullaby seen"
MANDIBUZZ_SEEN = "Mandibuzz seen"
HEATMOR_SEEN = "Heatmor seen"
DURANT_SEEN = "Durant seen"
DEINO_SEEN = "Deino seen"
ZWEILOUS_SEEN = "Zweilous seen"
HYDREIGON_SEEN = "Hydreigon seen"
LARVESTA_SEEN = "Larvesta seen"
VOLCARONA_SEEN = "Volcarona seen"
COBALION_SEEN = "Cobalion seen"
TERRAKION_SEEN = "Terrakion seen"
VIRIZION_SEEN = "Virizion seen"
TORNADUS_SEEN = "Tornadus seen"
THUNDURUS_SEEN = "Thundurus seen"
RESHIRAM_SEEN = "Reshiram seen"
ZEKROM_SEEN = "Zekrom seen"
LANDORUS_SEEN = "Landorus seen"
KYUREM_SEEN = "Kyurem seen"
KELDEO_SEEN = "Keldeo seen"
MELOETTA_SEEN = "Meloetta seen"
GENESECT_SEEN = "Genesect seen"
CHESPIN_SEEN = "Chespin seen"
QUILLADIN_SEEN = "Quilladin seen"
CHESNAUGHT_SEEN = "Chesnaught seen"
FENNEKIN_SEEN = "Fennekin seen"
BRAIXEN_SEEN = "Braixen seen"
DELPHOX_SEEN = "Delphox seen"
FROAKIE_SEEN = "Froakie seen"
FROGADIER_SEEN = "Frogadier seen"
GRENINJA_SEEN = "Greninja seen"
BUNNELBY_SEEN = "Bunnelby seen"
DIGGERSBY_SEEN = "Diggersby seen"
FLETCHLING_SEEN = "Fletchling seen"
FLETCHINDER_SEEN = "Fletchinder seen"
TALONFLAME_SEEN = "Talonflame seen"
SCATTERBUG_SEEN = "Scatterbug seen"
SPEWPA_SEEN = "Spewpa seen"
VIVILLON_SEEN = "Vivillon seen"
LITLEO_SEEN = "Litleo seen"
PYROAR_SEEN = "Pyroar seen"
FLABEBE_SEEN = "Flabébé seen"
FLOETTE_SEEN = "Floette seen"
FLORGES_SEEN = "Florges seen"
SKIDDO_SEEN = "Skiddo seen"
GOGOAT_SEEN = "Gogoat seen"
PANCHAM_SEEN = "Pancham seen"
PANGORO_SEEN = "Pangoro seen"
FURFROU_SEEN = "Furfrou seen"
ESPURR_SEEN = "Espurr seen"
MEOWSTIC_SEEN = "Meowstic seen"
HONEDGE_SEEN = "Honedge seen"
DOUBLADE_SEEN = "Doublade seen"
AEGISLASH_SEEN = "Aegislash seen"
SPRITZEE_SEEN = "Spritzee seen"
AROMATISSE_SEEN = "Aromatisse seen"
SWIRLIX_SEEN = "Swirlix seen"
SLURPUFF_SEEN = "Slurpuff seen"
INKAY_SEEN = "Inkay seen"
MALAMAR_SEEN = "Malamar seen"
BINACLE_SEEN = "Binacle seen"
BARBARACLE_SEEN = "Barbaracle seen"
SKRELP_SEEN = "Skrelp seen"
DRAGALGE_SEEN = "Dragalge seen"
CLAUNCHER_SEEN = "Clauncher seen"
CLAWITZER_SEEN = "Clawitzer seen"
HELIOPTILE_SEEN = "Helioptile seen"
HELIOLISK_SEEN = "Heliolisk seen"
TYRUNT_SEEN = "Tyrunt seen"
TYRANTRUM_SEEN = "Tyrantrum seen"
AMAURA_SEEN = "Amaura seen"
AURORUS_SEEN = "Aurorus seen"
SYLVEON_SEEN = "Sylveon seen"
HAWLUCHA_SEEN = "Hawlucha seen"
DEDENNE_SEEN = "Dedenne seen"
CARBINK_SEEN = "Carbink seen"
GOOMY_SEEN = "Goomy seen"
SLIGGOO_SEEN = "Sliggoo seen"
GOODRA_SEEN = "Goodra seen"
KLEFKI_SEEN = "Klefki seen"
PHANTUMP_SEEN = "Phantump seen"
TREVENANT_SEEN = "Trevenant seen"
PUMPKABOO_SEEN = "Pumpkaboo seen"
GOURGEIST_SEEN = "Gourgeist seen"
BERGMITE_SEEN = "Bergmite seen"
AVALUGG_SEEN = "Avalugg seen"
NOIBAT_SEEN = "Noibat seen"
NOIVERN_SEEN = "Noivern seen"
XERNEAS_SEEN = "Xerneas seen"
YVELTAL_SEEN = "Yveltal seen"
ZYGARDE_SEEN = "Zygarde seen"
DIANCIE_SEEN = "Diancie seen"
HOOPA_SEEN = "Hoopa seen"
VOLCANION_SEEN = "Volcanion seen"
ROWLET_SEEN = "Rowlet seen"
DARTRIX_SEEN = "Dartrix seen"
DECIDUEYE_SEEN = "Decidueye seen"
LITTEN_SEEN = "Litten seen"
TORRACAT_SEEN = "Torracat seen"
INCINEROAR_SEEN = "Incineroar seen"
POPPLIO_SEEN = "Popplio seen"
BRIONNE_SEEN = "Brionne seen"
PRIMARINA_SEEN = "Primarina seen"
PIKIPEK_SEEN = "Pikipek seen"
TRUMBEAK_SEEN = "Trumbeak seen"
TOUCANNON_SEEN = "Toucannon seen"
YUNGOOS_SEEN = "Yungoos seen"
GUMSHOOS_SEEN = "Gumshoos seen"
GRUBBIN_SEEN = "Grubbin seen"
CHARJABUG_SEEN = "Charjabug seen"
VIKAVOLT_SEEN = "Vikavolt seen"
CRABRAWLER_SEEN = "Crabrawler seen"
CRABOMINABLE_SEEN = "Crabominable seen"
ORICORIO_SEEN = "Oricorio seen"
CUTIEFLY_SEEN = "Cutiefly seen"
RIBOMBEE_SEEN = "Ribombee seen"
ROCKRUFF_SEEN = "Rockruff seen"
LYCANROC_SEEN = "Lycanroc seen"
WISHIWASHI_SEEN = "Wishiwashi seen"
MAREANIE_SEEN = "Mareanie seen"
TOXAPEX_SEEN = "Toxapex seen"
MUDBRAY_SEEN = "Mudbray seen"
MUDSDALE_SEEN = "Mudsdale seen"
DEWPIDER_SEEN = "Dewpider seen"
ARAQUANID_SEEN = "Araquanid seen"
FOMANTIS_SEEN = "Fomantis seen"
LURANTIS_SEEN = "Lurantis seen"
MORELULL_SEEN = "Morelull seen"
SHIINOTIC_SEEN = "Shiinotic seen"
SALANDIT_SEEN = "Salandit seen"
SALAZZLE_SEEN = "Salazzle seen"
STUFFUL_SEEN = "Stufful seen"
BEWEAR_SEEN = "Bewear seen"
BOUNSWEET_SEEN = "Bounsweet seen"
STEENEE_SEEN = "Steenee seen"
TSAREENA_SEEN = "Tsareena seen"
COMFEY_SEEN = "Comfey seen"
ORANGURU_SEEN = "Oranguru seen"
PASSIMIAN_SEEN = "Passimian seen"
WIMPOD_SEEN = "Wimpod seen"
GOLISOPOD_SEEN = "Golisopod seen"
SANDYGAST_SEEN = "Sandygast seen"
PALOSSAND_SEEN = "Palossand seen"
PYUKUMUKU_SEEN = "Pyukumuku seen"
TYPENULL_SEEN = "Type: Null seen"
SILVALLY_SEEN = "Silvally seen"
MINIOR_SEEN = "Minior seen"
KOMALA_SEEN = "Komala seen"
TURTONATOR_SEEN = "Turtonator seen"
TOGEDEMARU_SEEN = "Togedemaru seen"
MIMIKYU_SEEN = "Mimikyu seen"
BRUXISH_SEEN = "Bruxish seen"
DRAMPA_SEEN = "Drampa seen"
DHELMISE_SEEN = "Dhelmise seen"
JANGMO_O_SEEN = "Jangmo-o seen"
HAKAMO_O_SEEN = "Hakamo-o seen"
KOMMO_O_SEEN = "Kommo-o seen"
TAPUKOKO_SEEN = "Tapu Koko seen"
TAPULELE_SEEN = "Tapu Lele seen"
TAPUBULU_SEEN = "Tapu Bulu seen"
TAPUFINI_SEEN = "Tapu Fini seen"
COSMOG_SEEN = "Cosmog seen"
COSMOEM_SEEN = "Cosmoem seen"
SOLGALEO_SEEN = "Solgaleo seen"
LUNALA_SEEN = "Lunala seen"
NIHILEGO_SEEN = "Nihilego seen"
BUZZWOLE_SEEN = "Buzzwole seen"
PHEROMOSA_SEEN = "Pheromosa seen"
XURKITREE_SEEN = "Xurkitree seen"
CELESTEELA_SEEN = "Celesteela seen"
KARTANA_SEEN = "Kartana seen"
GUZZLORD_SEEN = "Guzzlord seen"
NECROZMA_SEEN = "Necrozma seen"
MAGEARNA_SEEN = "Magearna seen"
MARSHADOW_SEEN = "Marshadow seen"
POIPOLE_SEEN = "Poipole seen"
NAGANADEL_SEEN = "Naganadel seen"
STAKATAKA_SEEN = "Stakataka seen"
BLACEPHALON_SEEN = "Blacephalon seen"
ZERAORA_SEEN = "Zeraora seen"
MELTAN_SEEN = "Meltan seen"
MELMETAL_SEEN = "Melmetal seen"
GROOKEY_SEEN = "Grookey seen"
THWACKEY_SEEN = "Thwackey seen"
RILLABOOM_SEEN = "Rillaboom seen"
SCORBUNNY_SEEN = "Scorbunny seen"
RABOOT_SEEN = "Raboot seen"
CINDERACE_SEEN = "Cinderace seen"
SOBBLE_SEEN = "Sobble seen"
DRIZZILE_SEEN = "Drizzile seen"
INTELEON_SEEN = "Inteleon seen"
SKWOVET_SEEN = "Skwovet seen"
GREEDENT_SEEN = "Greedent seen"
ROOKIDEE_SEEN = "Rookidee seen"
CORVISQUIRE_SEEN = "Corvisquire seen"
CORVIKNIGHT_SEEN = "Corviknight seen"
BLIPBUG_SEEN = "Blipbug seen"
DOTTLER_SEEN = "Dottler seen"
ORBEETLE_SEEN = "Orbeetle seen"
NICKIT_SEEN = "Nickit seen"
THIEVUL_SEEN = "Thievul seen"
GOSSIFLEUR_SEEN = "Gossifleur seen"
ELDEGOSS_SEEN = "Eldegoss seen"
WOOLOO_SEEN = "Wooloo seen"
DUBWOOL_SEEN = "Dubwool seen"
CHEWTLE_SEEN = "Chewtle seen"
DREDNAW_SEEN = "Drednaw seen"
YAMPER_SEEN = "Yamper seen"
BOLTUND_SEEN = "Boltund seen"
ROLYCOLY_SEEN = "Rolycoly seen"
CARKOL_SEEN = "Carkol seen"
COALOSSAL_SEEN = "Coalossal seen"
APPLIN_SEEN = "Applin seen"
FLAPPLE_SEEN = "Flapple seen"
APPLETUN_SEEN = "Appletun seen"
SILICOBRA_SEEN = "Silicobra seen"
SANDACONDA_SEEN = "Sandaconda seen"
CRAMORANT_SEEN = "Cramorant seen"
ARROKUDA_SEEN = "Arrokuda seen"
BARRASKEWDA_SEEN = "Barraskewda seen"
TOXEL_SEEN = "Toxel seen"
TOXTRICITY_SEEN = "Toxtricity seen"
SIZZLIPEDE_SEEN = "Sizzlipede seen"
CENTISKORCH_SEEN = "Centiskorch seen"
CLOBBOPUS_SEEN = "Clobbopus seen"
GRAPPLOCT_SEEN = "Grapploct seen"
SINISTEA_SEEN = "Sinistea seen"
POLTEAGEIST_SEEN = "Polteageist seen"
HATENNA_SEEN = "Hatenna seen"
HATTREM_SEEN = "Hattrem seen"
HATTERENE_SEEN = "Hatterene seen"
IMPIDIMP_SEEN = "Impidimp seen"
MORGREM_SEEN = "Morgrem seen"
GRIMMSNARL_SEEN = "Grimmsnarl seen"
OBSTAGOON_SEEN = "Obstagoon seen"
PERRSERKER_SEEN = "Perrserker seen"
CURSOLA_SEEN = "Cursola seen"
SIRFETCHD_SEEN = "Sirfetch'd seen"
MRRIME_SEEN = "Mr. Rime seen"
RUNERIGUS_SEEN = "Runerigus seen"
MILCERY_SEEN = "Milcery seen"
ALCREMIE_SEEN = "Alcremie seen"
FALINKS_SEEN = "Falinks seen"
PINCURCHIN_SEEN = "Pincurchin seen"
SNOM_SEEN = "Snom seen"
FROSMOTH_SEEN = "Frosmoth seen"
STONJOURNER_SEEN = "Stonjourner seen"
EISCUE_SEEN = "Eiscue seen"
INDEEDEE_SEEN = "Indeedee seen"
MORPEKO_SEEN = "Morpeko seen"
CUFANT_SEEN = "Cufant seen"
COPPERAJAH_SEEN = "Copperajah seen"
DRACOZOLT_SEEN = "Dracozolt seen"
ARCTOZOLT_SEEN = "Arctozolt seen"
DRACOVISH_SEEN = "Dracovish seen"
ARCTOVISH_SEEN = "Arctovish seen"
DURALUDON_SEEN = "Duraludon seen"
DREEPY_SEEN = "Dreepy seen"
DRAKLOAK_SEEN = "Drakloak seen"
DRAGAPULT_SEEN = "Dragapult seen"
ZACIAN_SEEN = "Zacian seen"
ZAMAZENTA_SEEN = "Zamazenta seen"
ETERNATUS_SEEN = "Eternatus seen"
KUBFU_SEEN = "Kubfu seen"
URSHIFU_SEEN = "Urshifu seen"
ZARUDE_SEEN = "Zarude seen"
REGIELEKI_SEEN = "Regieleki seen"
REGIDRAGO_SEEN = "Regidrago seen"
GLASTRIER_SEEN = "Glastrier seen"
SPECTRIER_SEEN = "Spectrier seen"
CALYREX_SEEN = "Calyrex seen"

BULBASAUR_OWNED = "Bulbasaur owned"
IVYSAUR_OWNED = "Ivysaur owned"
VENUSAUR_OWNED = "Venusaur owned"
CHARMANDER_OWNED = "Charmander owned"
CHARMELEON_OWNED = "Charmeleon owned"
CHARIZARD_OWNED = "Charizard owned"
SQUIRTLE_OWNED = "Squirtle owned"
WARTORTLE_OWNED = "Wartortle owned"
BLASTOISE_OWNED = "Blastoise owned"
CATERPIE_OWNED = "Caterpie owned"
METAPOD_OWNED = "Metapod owned"
BUTTERFREE_OWNED = "Butterfree owned"
WEEDLE_OWNED = "Weedle owned"
KAKUNA_OWNED = "Kakuna owned"
BEEDRILL_OWNED = "Beedrill owned"
PIDGEY_OWNED = "Pidgey owned"
PIDGEOTTO_OWNED = "Pidgeotto owned"
PIDGEOT_OWNED = "Pidgeot owned"
RATTATA_OWNED = "Rattata owned"
RATICATE_OWNED = "Raticate owned"
SPEAROW_OWNED = "Spearow owned"
FEAROW_OWNED = "Fearow owned"
EKANS_OWNED = "Ekans owned"
ARBOK_OWNED = "Arbok owned"
PIKACHU_OWNED = "Pikachu owned"
RAICHU_OWNED = "Raichu owned"
SANDSHREW_OWNED = "Sandshrew owned"
SANDSLASH_OWNED = "Sandslash owned"
NIDORAN_F_OWNED = "Nidoran♀ owned"
NIDORINA_OWNED = "Nidorina owned"
NIDOQUEEN_OWNED = "Nidoqueen owned"
NIDORAN_M_OWNED = "Nidoran♂ owned"
NIDORINO_OWNED = "Nidorino owned"
NIDOKING_OWNED = "Nidoking owned"
CLEFAIRY_OWNED = "Clefairy owned"
CLEFABLE_OWNED = "Clefable owned"
VULPIX_OWNED = "Vulpix owned"
NINETALES_OWNED = "Ninetales owned"
JIGGLYPUFF_OWNED = "Jigglypuff owned"
WIGGLYTUFF_OWNED = "Wigglytuff owned"
ZUBAT_OWNED = "Zubat owned"
GOLBAT_OWNED = "Golbat owned"
ODDISH_OWNED = "Oddish owned"
GLOOM_OWNED = "Gloom owned"
VILEPLUME_OWNED = "Vileplume owned"
PARAS_OWNED = "Paras owned"
PARASECT_OWNED = "Parasect owned"
VENONAT_OWNED = "Venonat owned"
VENOMOTH_OWNED = "Venomoth owned"
DIGLETT_OWNED = "Diglett owned"
DUGTRIO_OWNED = "Dugtrio owned"
MEOWTH_OWNED = "Meowth owned"
PERSIAN_OWNED = "Persian owned"
PSYDUCK_OWNED = "Psyduck owned"
GOLDUCK_OWNED = "Golduck owned"
MANKEY_OWNED = "Mankey owned"
PRIMEAPE_OWNED = "Primeape owned"
GROWLITHE_OWNED = "Growlithe owned"
ARCANINE_OWNED = "Arcanine owned"
POLIWAG_OWNED = "Poliwag owned"
POLIWHIRL_OWNED = "Poliwhirl owned"
POLIWRATH_OWNED = "Poliwrath owned"
ABRA_OWNED = "Abra owned"
KADABRA_OWNED = "Kadabra owned"
ALAKAZAM_OWNED = "Alakazam owned"
MACHOP_OWNED = "Machop owned"
MACHOKE_OWNED = "Machoke owned"
MACHAMP_OWNED = "Machamp owned"
BELLSPROUT_OWNED = "Bellsprout owned"
WEEPINBELL_OWNED = "Weepinbell owned"
VICTREEBEL_OWNED = "Victreebel owned"
TENTACOOL_OWNED = "Tentacool owned"
TENTACRUEL_OWNED = "Tentacruel owned"
GEODUDE_OWNED = "Geodude owned"
GRAVELER_OWNED = "Graveler owned"
GOLEM_OWNED = "Golem owned"
PONYTA_OWNED = "Ponyta owned"
RAPIDASH_OWNED = "Rapidash owned"
SLOWPOKE_OWNED = "Slowpoke owned"
SLOWBRO_OWNED = "Slowbro owned"
MAGNEMITE_OWNED = "Magnemite owned"
MAGNETON_OWNED = "Magneton owned"
FARFETCHD_OWNED = "Farfetch'd owned"
DODUO_OWNED = "Doduo owned"
DODRIO_OWNED = "Dodrio owned"
SEEL_OWNED = "Seel owned"
DEWGONG_OWNED = "Dewgong owned"
GRIMER_OWNED = "Grimer owned"
MUK_OWNED = "Muk owned"
SHELLDER_OWNED = "Shellder owned"
CLOYSTER_OWNED = "Cloyster owned"
GASTLY_OWNED = "Gastly owned"
HAUNTER_OWNED = "Haunter owned"
GENGAR_OWNED = "Gengar owned"
ONIX_OWNED = "Onix owned"
DROWZEE_OWNED = "Drowzee owned"
HYPNO_OWNED = "Hypno owned"
KRABBY_OWNED = "Krabby owned"
KINGLER_OWNED = "Kingler owned"
VOLTORB_OWNED = "Voltorb owned"
ELECTRODE_OWNED = "Electrode owned"
EXEGGCUTE_OWNED = "Exeggcute owned"
EXEGGUTOR_OWNED = "Exeggutor owned"
CUBONE_OWNED = "Cubone owned"
MAROWAK_OWNED = "Marowak owned"
HITMONLEE_OWNED = "Hitmonlee owned"
HITMONCHAN_OWNED = "Hitmonchan owned"
LICKITUNG_OWNED = "Lickitung owned"
KOFFING_OWNED = "Koffing owned"
WEEZING_OWNED = "Weezing owned"
RHYHORN_OWNED = "Rhyhorn owned"
RHYDON_OWNED = "Rhydon owned"
CHANSEY_OWNED = "Chansey owned"
TANGELA_OWNED = "Tangela owned"
KANGASKHAN_OWNED = "Kangaskhan owned"
HORSEA_OWNED = "Horsea owned"
SEADRA_OWNED = "Seadra owned"
GOLDEEN_OWNED = "Goldeen owned"
SEAKING_OWNED = "Seaking owned"
STARYU_OWNED = "Staryu owned"
STARMIE_OWNED = "Starmie owned"
MRMIME_OWNED = "Mr. Mime owned"
SCYTHER_OWNED = "Scyther owned"
JYNX_OWNED = "Jynx owned"
ELECTABUZZ_OWNED = "Electabuzz owned"
MAGMAR_OWNED = "Magmar owned"
PINSIR_OWNED = "Pinsir owned"
TAUROS_OWNED = "Tauros owned"
MAGIKARP_OWNED = "Magikarp owned"
GYARADOS_OWNED = "Gyarados owned"
LAPRAS_OWNED = "Lapras owned"
DITTO_OWNED = "Ditto owned"
EEVEE_OWNED = "Eevee owned"
VAPOREON_OWNED = "Vaporeon owned"
JOLTEON_OWNED = "Jolteon owned"
FLAREON_OWNED = "Flareon owned"
PORYGON_OWNED = "Porygon owned"
OMANYTE_OWNED = "Omanyte owned"
OMASTAR_OWNED = "Omastar owned"
KABUTO_OWNED = "Kabuto owned"
KABUTOPS_OWNED = "Kabutops owned"
AERODACTYL_OWNED = "Aerodactyl owned"
SNORLAX_OWNED = "Snorlax owned"
ARTICUNO_OWNED = "Articuno owned"
ZAPDOS_OWNED = "Zapdos owned"
MOLTRES_OWNED = "Moltres owned"
DRATINI_OWNED = "Dratini owned"
DRAGONAIR_OWNED = "Dragonair owned"
DRAGONITE_OWNED = "Dragonite owned"
MEWTWO_OWNED = "Mewtwo owned"
MEW_OWNED = "Mew owned"
CHIKORITA_OWNED = "Chikorita owned"
BAYLEEF_OWNED = "Bayleef owned"
MEGANIUM_OWNED = "Meganium owned"
CYNDAQUIL_OWNED = "Cyndaquil owned"
QUILAVA_OWNED = "Quilava owned"
TYPHLOSION_OWNED = "Typhlosion owned"
TOTODILE_OWNED = "Totodile owned"
CROCONAW_OWNED = "Croconaw owned"
FERALIGATR_OWNED = "Feraligatr owned"
SENTRET_OWNED = "Sentret owned"
FURRET_OWNED = "Furret owned"
HOOTHOOT_OWNED = "Hoothoot owned"
NOCTOWL_OWNED = "Noctowl owned"
LEDYBA_OWNED = "Ledyba owned"
LEDIAN_OWNED = "Ledian owned"
SPINARAK_OWNED = "Spinarak owned"
ARIADOS_OWNED = "Ariados owned"
CROBAT_OWNED = "Crobat owned"
CHINCHOU_OWNED = "Chinchou owned"
LANTURN_OWNED = "Lanturn owned"
PICHU_OWNED = "Pichu owned"
CLEFFA_OWNED = "Cleffa owned"
IGGLYBUFF_OWNED = "Igglybuff owned"
TOGEPI_OWNED = "Togepi owned"
TOGETIC_OWNED = "Togetic owned"
NATU_OWNED = "Natu owned"
XATU_OWNED = "Xatu owned"
MAREEP_OWNED = "Mareep owned"
FLAAFFY_OWNED = "Flaaffy owned"
AMPHAROS_OWNED = "Ampharos owned"
BELLOSSOM_OWNED = "Bellossom owned"
MARILL_OWNED = "Marill owned"
AZUMARILL_OWNED = "Azumarill owned"
SUDOWOODO_OWNED = "Sudowoodo owned"
POLITOED_OWNED = "Politoed owned"
HOPPIP_OWNED = "Hoppip owned"
SKIPLOOM_OWNED = "Skiploom owned"
JUMPLUFF_OWNED = "Jumpluff owned"
AIPOM_OWNED = "Aipom owned"
SUNKERN_OWNED = "Sunkern owned"
SUNFLORA_OWNED = "Sunflora owned"
YANMA_OWNED = "Yanma owned"
WOOPER_OWNED = "Wooper owned"
QUAGSIRE_OWNED = "Quagsire owned"
ESPEON_OWNED = "Espeon owned"
UMBREON_OWNED = "Umbreon owned"
MURKROW_OWNED = "Murkrow owned"
SLOWKING_OWNED = "Slowking owned"
MISDREAVUS_OWNED = "Misdreavus owned"
UNOWN_OWNED = "Unown owned"
WOBBUFFET_OWNED = "Wobbuffet owned"
GIRAFARIG_OWNED = "Girafarig owned"
PINECO_OWNED = "Pineco owned"
FORRETRESS_OWNED = "Forretress owned"
DUNSPARCE_OWNED = "Dunsparce owned"
GLIGAR_OWNED = "Gligar owned"
STEELIX_OWNED = "Steelix owned"
SNUBBULL_OWNED = "Snubbull owned"
GRANBULL_OWNED = "Granbull owned"
QWILFISH_OWNED = "Qwilfish owned"
SCIZOR_OWNED = "Scizor owned"
SHUCKLE_OWNED = "Shuckle owned"
HERACROSS_OWNED = "Heracross owned"
SNEASEL_OWNED = "Sneasel owned"
TEDDIURSA_OWNED = "Teddiursa owned"
URSARING_OWNED = "Ursaring owned"
SLUGMA_OWNED = "Slugma owned"
MAGCARGO_OWNED = "Magcargo owned"
SWINUB_OWNED = "Swinub owned"
PILOSWINE_OWNED = "Piloswine owned"
CORSOLA_OWNED = "Corsola owned"
REMORAID_OWNED = "Remoraid owned"
OCTILLERY_OWNED = "Octillery owned"
DELIBIRD_OWNED = "Delibird owned"
MANTINE_OWNED = "Mantine owned"
SKARMORY_OWNED = "Skarmory owned"
HOUNDOUR_OWNED = "Houndour owned"
HOUNDOOM_OWNED = "Houndoom owned"
KINGDRA_OWNED = "Kingdra owned"
PHANPY_OWNED = "Phanpy owned"
DONPHAN_OWNED = "Donphan owned"
PORYGON2_OWNED = "Porygon2 owned"
STANTLER_OWNED = "Stantler owned"
SMEARGLE_OWNED = "Smeargle owned"
TYROGUE_OWNED = "Tyrogue owned"
HITMONTOP_OWNED = "Hitmontop owned"
SMOOCHUM_OWNED = "Smoochum owned"
ELEKID_OWNED = "Elekid owned"
MAGBY_OWNED = "Magby owned"
MILTANK_OWNED = "Miltank owned"
BLISSEY_OWNED = "Blissey owned"
RAIKOU_OWNED = "Raikou owned"
ENTEI_OWNED = "Entei owned"
SUICUNE_OWNED = "Suicune owned"
LARVITAR_OWNED = "Larvitar owned"
PUPITAR_OWNED = "Pupitar owned"
TYRANITAR_OWNED = "Tyranitar owned"
LUGIA_OWNED = "Lugia owned"
HO_OH_OWNED = "Ho-Oh owned"
CELEBI_OWNED = "Celebi owned"
TREECKO_OWNED = "Treecko owned"
GROVYLE_OWNED = "Grovyle owned"
SCEPTILE_OWNED = "Sceptile owned"
TORCHIC_OWNED = "Torchic owned"
COMBUSKEN_OWNED = "Combusken owned"
BLAZIKEN_OWNED = "Blaziken owned"
MUDKIP_OWNED = "Mudkip owned"
MARSHTOMP_OWNED = "Marshtomp owned"
SWAMPERT_OWNED = "Swampert owned"
POOCHYENA_OWNED = "Poochyena owned"
MIGHTYENA_OWNED = "Mightyena owned"
ZIGZAGOON_OWNED = "Zigzagoon owned"
LINOONE_OWNED = "Linoone owned"
WURMPLE_OWNED = "Wurmple owned"
SILCOON_OWNED = "Silcoon owned"
BEAUTIFLY_OWNED = "Beautifly owned"
CASCOON_OWNED = "Cascoon owned"
DUSTOX_OWNED = "Dustox owned"
LOTAD_OWNED = "Lotad owned"
LOMBRE_OWNED = "Lombre owned"
LUDICOLO_OWNED = "Ludicolo owned"
SEEDOT_OWNED = "Seedot owned"
NUZLEAF_OWNED = "Nuzleaf owned"
SHIFTRY_OWNED = "Shiftry owned"
TAILLOW_OWNED = "Taillow owned"
SWELLOW_OWNED = "Swellow owned"
WINGULL_OWNED = "Wingull owned"
PELIPPER_OWNED = "Pelipper owned"
RALTS_OWNED = "Ralts owned"
KIRLIA_OWNED = "Kirlia owned"
GARDEVOIR_OWNED = "Gardevoir owned"
SURSKIT_OWNED = "Surskit owned"
MASQUERAIN_OWNED = "Masquerain owned"
SHROOMISH_OWNED = "Shroomish owned"
BRELOOM_OWNED = "Breloom owned"
SLAKOTH_OWNED = "Slakoth owned"
VIGOROTH_OWNED = "Vigoroth owned"
SLAKING_OWNED = "Slaking owned"
NINCADA_OWNED = "Nincada owned"
NINJASK_OWNED = "Ninjask owned"
SHEDINJA_OWNED = "Shedinja owned"
WHISMUR_OWNED = "Whismur owned"
LOUDRED_OWNED = "Loudred owned"
EXPLOUD_OWNED = "Exploud owned"
MAKUHITA_OWNED = "Makuhita owned"
HARIYAMA_OWNED = "Hariyama owned"
AZURILL_OWNED = "Azurill owned"
NOSEPASS_OWNED = "Nosepass owned"
SKITTY_OWNED = "Skitty owned"
DELCATTY_OWNED = "Delcatty owned"
SABLEYE_OWNED = "Sableye owned"
MAWILE_OWNED = "Mawile owned"
ARON_OWNED = "Aron owned"
LAIRON_OWNED = "Lairon owned"
AGGRON_OWNED = "Aggron owned"
MEDITITE_OWNED = "Meditite owned"
MEDICHAM_OWNED = "Medicham owned"
ELECTRIKE_OWNED = "Electrike owned"
MANECTRIC_OWNED = "Manectric owned"
PLUSLE_OWNED = "Plusle owned"
MINUN_OWNED = "Minun owned"
VOLBEAT_OWNED = "Volbeat owned"
ILLUMISE_OWNED = "Illumise owned"
ROSELIA_OWNED = "Roselia owned"
GULPIN_OWNED = "Gulpin owned"
SWALOT_OWNED = "Swalot owned"
CARVANHA_OWNED = "Carvanha owned"
SHARPEDO_OWNED = "Sharpedo owned"
WAILMER_OWNED = "Wailmer owned"
WAILORD_OWNED = "Wailord owned"
NUMEL_OWNED = "Numel owned"
CAMERUPT_OWNED = "Camerupt owned"
TORKOAL_OWNED = "Torkoal owned"
SPOINK_OWNED = "Spoink owned"
GRUMPIG_OWNED = "Grumpig owned"
SPINDA_OWNED = "Spinda owned"
TRAPINCH_OWNED = "Trapinch owned"
VIBRAVA_OWNED = "Vibrava owned"
FLYGON_OWNED = "Flygon owned"
CACNEA_OWNED = "Cacnea owned"
CACTURNE_OWNED = "Cacturne owned"
SWABLU_OWNED = "Swablu owned"
ALTARIA_OWNED = "Altaria owned"
ZANGOOSE_OWNED = "Zangoose owned"
SEVIPER_OWNED = "Seviper owned"
LUNATONE_OWNED = "Lunatone owned"
SOLROCK_OWNED = "Solrock owned"
BARBOACH_OWNED = "Barboach owned"
WHISCASH_OWNED = "Whiscash owned"
CORPHISH_OWNED = "Corphish owned"
CRAWDAUNT_OWNED = "Crawdaunt owned"
BALTOY_OWNED = "Baltoy owned"
CLAYDOL_OWNED = "Claydol owned"
LILEEP_OWNED = "Lileep owned"
CRADILY_OWNED = "Cradily owned"
ANORITH_OWNED = "Anorith owned"
ARMALDO_OWNED = "Armaldo owned"
FEEBAS_OWNED = "Feebas owned"
MILOTIC_OWNED = "Milotic owned"
CASTFORM_OWNED = "Castform owned"
KECLEON_OWNED = "Kecleon owned"
SHUPPET_OWNED = "Shuppet owned"
BANETTE_OWNED = "Banette owned"
DUSKULL_OWNED = "Duskull owned"
DUSCLOPS_OWNED = "Dusclops owned"
TROPIUS_OWNED = "Tropius owned"
CHIMECHO_OWNED = "Chimecho owned"
ABSOL_OWNED = "Absol owned"
WYNAUT_OWNED = "Wynaut owned"
SNORUNT_OWNED = "Snorunt owned"
GLALIE_OWNED = "Glalie owned"
SPHEAL_OWNED = "Spheal owned"
SEALEO_OWNED = "Sealeo owned"
WALREIN_OWNED = "Walrein owned"
CLAMPERL_OWNED = "Clamperl owned"
HUNTAIL_OWNED = "Huntail owned"
GOREBYSS_OWNED = "Gorebyss owned"
RELICANTH_OWNED = "Relicanth owned"
LUVDISC_OWNED = "Luvdisc owned"
BAGON_OWNED = "Bagon owned"
SHELGON_OWNED = "Shelgon owned"
SALAMENCE_OWNED = "Salamence owned"
BELDUM_OWNED = "Beldum owned"
METANG_OWNED = "Metang owned"
METAGROSS_OWNED = "Metagross owned"
REGIROCK_OWNED = "Regirock owned"
REGICE_OWNED = "Regice owned"
REGISTEEL_OWNED = "Registeel owned"
LATIAS_OWNED = "Latias owned"
LATIOS_OWNED = "Latios owned"
KYOGRE_OWNED = "Kyogre owned"
GROUDON_OWNED = "Groudon owned"
RAYQUAZA_OWNED = "Rayquaza owned"
JIRACHI_OWNED = "Jirachi owned"
DEOXYS_OWNED = "Deoxys owned"
TURTWIG_OWNED = "Turtwig owned"
GROTLE_OWNED = "Grotle owned"
TORTERRA_OWNED = "Torterra owned"
CHIMCHAR_OWNED = "Chimchar owned"
MONFERNO_OWNED = "Monferno owned"
INFERNAPE_OWNED = "Infernape owned"
PIPLUP_OWNED = "Piplup owned"
PRINPLUP_OWNED = "Prinplup owned"
EMPOLEON_OWNED = "Empoleon owned"
STARLY_OWNED = "Starly owned"
STARAVIA_OWNED = "Staravia owned"
STARAPTOR_OWNED = "Staraptor owned"
BIDOOF_OWNED = "Bidoof owned"
BIBAREL_OWNED = "Bibarel owned"
KRICKETOT_OWNED = "Kricketot owned"
KRICKETUNE_OWNED = "Kricketune owned"
SHINX_OWNED = "Shinx owned"
LUXIO_OWNED = "Luxio owned"
LUXRAY_OWNED = "Luxray owned"
BUDEW_OWNED = "Budew owned"
ROSERADE_OWNED = "Roserade owned"
CRANIDOS_OWNED = "Cranidos owned"
RAMPARDOS_OWNED = "Rampardos owned"
SHIELDON_OWNED = "Shieldon owned"
BASTIODON_OWNED = "Bastiodon owned"
BURMY_OWNED = "Burmy owned"
WORMADAM_OWNED = "Wormadam owned"
MOTHIM_OWNED = "Mothim owned"
COMBEE_OWNED = "Combee owned"
VESPIQUEN_OWNED = "Vespiquen owned"
PACHIRISU_OWNED = "Pachirisu owned"
BUIZEL_OWNED = "Buizel owned"
FLOATZEL_OWNED = "Floatzel owned"
CHERUBI_OWNED = "Cherubi owned"
CHERRIM_OWNED = "Cherrim owned"
SHELLOS_OWNED = "Shellos owned"
GASTRODON_OWNED = "Gastrodon owned"
AMBIPOM_OWNED = "Ambipom owned"
DRIFLOON_OWNED = "Drifloon owned"
DRIFBLIM_OWNED = "Drifblim owned"
BUNEARY_OWNED = "Buneary owned"
LOPUNNY_OWNED = "Lopunny owned"
MISMAGIUS_OWNED = "Mismagius owned"
HONCHKROW_OWNED = "Honchkrow owned"
GLAMEOW_OWNED = "Glameow owned"
PURUGLY_OWNED = "Purugly owned"
CHINGLING_OWNED = "Chingling owned"
STUNKY_OWNED = "Stunky owned"
SKUNTANK_OWNED = "Skuntank owned"
BRONZOR_OWNED = "Bronzor owned"
BRONZONG_OWNED = "Bronzong owned"
BONSLY_OWNED = "Bonsly owned"
MIMEJR_OWNED = "Mime Jr. owned"
HAPPINY_OWNED = "Happiny owned"
CHATOT_OWNED = "Chatot owned"
SPIRITOMB_OWNED = "Spiritomb owned"
GIBLE_OWNED = "Gible owned"
GABITE_OWNED = "Gabite owned"
GARCHOMP_OWNED = "Garchomp owned"
MUNCHLAX_OWNED = "Munchlax owned"
RIOLU_OWNED = "Riolu owned"
LUCARIO_OWNED = "Lucario owned"
HIPPOPOTAS_OWNED = "Hippopotas owned"
HIPPOWDON_OWNED = "Hippowdon owned"
SKORUPI_OWNED = "Skorupi owned"
DRAPION_OWNED = "Drapion owned"
CROAGUNK_OWNED = "Croagunk owned"
TOXICROAK_OWNED = "Toxicroak owned"
CARNIVINE_OWNED = "Carnivine owned"
FINNEON_OWNED = "Finneon owned"
LUMINEON_OWNED = "Lumineon owned"
MANTYKE_OWNED = "Mantyke owned"
SNOVER_OWNED = "Snover owned"
ABOMASNOW_OWNED = "Abomasnow owned"
WEAVILE_OWNED = "Weavile owned"
MAGNEZONE_OWNED = "Magnezone owned"
LICKILICKY_OWNED = "Lickilicky owned"
RHYPERIOR_OWNED = "Rhyperior owned"
TANGROWTH_OWNED = "Tangrowth owned"
ELECTIVIRE_OWNED = "Electivire owned"
MAGMORTAR_OWNED = "Magmortar owned"
TOGEKISS_OWNED = "Togekiss owned"
YANMEGA_OWNED = "Yanmega owned"
LEAFEON_OWNED = "Leafeon owned"
GLACEON_OWNED = "Glaceon owned"
GLISCOR_OWNED = "Gliscor owned"
MAMOSWINE_OWNED = "Mamoswine owned"
PORYGON_Z_OWNED = "Porygon-Z owned"
GALLADE_OWNED = "Gallade owned"
PROBOPASS_OWNED = "Probopass owned"
DUSKNOIR_OWNED = "Dusknoir owned"
FROSLASS_OWNED = "Froslass owned"
ROTOM_OWNED = "Rotom owned"
UXIE_OWNED = "Uxie owned"
MESPRIT_OWNED = "Mesprit owned"
AZELF_OWNED = "Azelf owned"
DIALGA_OWNED = "Dialga owned"
PALKIA_OWNED = "Palkia owned"
HEATRAN_OWNED = "Heatran owned"
REGIGIGAS_OWNED = "Regigigas owned"
GIRATINA_OWNED = "Giratina owned"
CRESSELIA_OWNED = "Cresselia owned"
PHIONE_OWNED = "Phione owned"
MANAPHY_OWNED = "Manaphy owned"
DARKRAI_OWNED = "Darkrai owned"
SHAYMIN_OWNED = "Shaymin owned"
ARCEUS_OWNED = "Arceus owned"
VICTINI_OWNED = "Victini owned"
SNIVY_OWNED = "Snivy owned"
SERVINE_OWNED = "Servine owned"
SERPERIOR_OWNED = "Serperior owned"
TEPIG_OWNED = "Tepig owned"
PIGNITE_OWNED = "Pignite owned"
EMBOAR_OWNED = "Emboar owned"
OSHAWOTT_OWNED = "Oshawott owned"
DEWOTT_OWNED = "Dewott owned"
SAMUROTT_OWNED = "Samurott owned"
PATRAT_OWNED = "Patrat owned"
WATCHOG_OWNED = "Watchog owned"
LILLIPUP_OWNED = "Lillipup owned"
HERDIER_OWNED = "Herdier owned"
STOUTLAND_OWNED = "Stoutland owned"
PURRLOIN_OWNED = "Purrloin owned"
LIEPARD_OWNED = "Liepard owned"
PANSAGE_OWNED = "Pansage owned"
SIMISAGE_OWNED = "Simisage owned"
PANSEAR_OWNED = "Pansear owned"
SIMISEAR_OWNED = "Simisear owned"
PANPOUR_OWNED = "Panpour owned"
SIMIPOUR_OWNED = "Simipour owned"
MUNNA_OWNED = "Munna owned"
MUSHARNA_OWNED = "Musharna owned"
PIDOVE_OWNED = "Pidove owned"
TRANQUILL_OWNED = "Tranquill owned"
UNFEZANT_OWNED = "Unfezant owned"
BLITZLE_OWNED = "Blitzle owned"
ZEBSTRIKA_OWNED = "Zebstrika owned"
ROGGENROLA_OWNED = "Roggenrola owned"
BOLDORE_OWNED = "Boldore owned"
GIGALITH_OWNED = "Gigalith owned"
WOOBAT_OWNED = "Woobat owned"
SWOOBAT_OWNED = "Swoobat owned"
DRILBUR_OWNED = "Drilbur owned"
EXCADRILL_OWNED = "Excadrill owned"
AUDINO_OWNED = "Audino owned"
TIMBURR_OWNED = "Timburr owned"
GURDURR_OWNED = "Gurdurr owned"
CONKELDURR_OWNED = "Conkeldurr owned"
TYMPOLE_OWNED = "Tympole owned"
PALPITOAD_OWNED = "Palpitoad owned"
SEISMITOAD_OWNED = "Seismitoad owned"
THROH_OWNED = "Throh owned"
SAWK_OWNED = "Sawk owned"
SEWADDLE_OWNED = "Sewaddle owned"
SWADLOON_OWNED = "Swadloon owned"
LEAVANNY_OWNED = "Leavanny owned"
VENIPEDE_OWNED = "Venipede owned"
WHIRLIPEDE_OWNED = "Whirlipede owned"
SCOLIPEDE_OWNED = "Scolipede owned"
COTTONEE_OWNED = "Cottonee owned"
WHIMSICOTT_OWNED = "Whimsicott owned"
PETILIL_OWNED = "Petilil owned"
LILLIGANT_OWNED = "Lilligant owned"
BASCULIN_OWNED = "Basculin owned"
SANDILE_OWNED = "Sandile owned"
KROKOROK_OWNED = "Krokorok owned"
KROOKODILE_OWNED = "Krookodile owned"
DARUMAKA_OWNED = "Darumaka owned"
DARMANITAN_OWNED = "Darmanitan owned"
MARACTUS_OWNED = "Maractus owned"
DWEBBLE_OWNED = "Dwebble owned"
CRUSTLE_OWNED = "Crustle owned"
SCRAGGY_OWNED = "Scraggy owned"
SCRAFTY_OWNED = "Scrafty owned"
SIGILYPH_OWNED = "Sigilyph owned"
YAMASK_OWNED = "Yamask owned"
COFAGRIGUS_OWNED = "Cofagrigus owned"
TIRTOUGA_OWNED = "Tirtouga owned"
CARRACOSTA_OWNED = "Carracosta owned"
ARCHEN_OWNED = "Archen owned"
ARCHEOPS_OWNED = "Archeops owned"
TRUBBISH_OWNED = "Trubbish owned"
GARBODOR_OWNED = "Garbodor owned"
ZORUA_OWNED = "Zorua owned"
ZOROARK_OWNED = "Zoroark owned"
MINCCINO_OWNED = "Minccino owned"
CINCCINO_OWNED = "Cinccino owned"
GOTHITA_OWNED = "Gothita owned"
GOTHORITA_OWNED = "Gothorita owned"
GOTHITELLE_OWNED = "Gothitelle owned"
SOLOSIS_OWNED = "Solosis owned"
DUOSION_OWNED = "Duosion owned"
REUNICLUS_OWNED = "Reuniclus owned"
DUCKLETT_OWNED = "Ducklett owned"
SWANNA_OWNED = "Swanna owned"
VANILLITE_OWNED = "Vanillite owned"
VANILLISH_OWNED = "Vanillish owned"
VANILLUXE_OWNED = "Vanilluxe owned"
DEERLING_OWNED = "Deerling owned"
SAWSBUCK_OWNED = "Sawsbuck owned"
EMOLGA_OWNED = "Emolga owned"
KARRABLAST_OWNED = "Karrablast owned"
ESCAVALIER_OWNED = "Escavalier owned"
FOONGUS_OWNED = "Foongus owned"
AMOONGUSS_OWNED = "Amoonguss owned"
FRILLISH_OWNED = "Frillish owned"
JELLICENT_OWNED = "Jellicent owned"
ALOMOMOLA_OWNED = "Alomomola owned"
JOLTIK_OWNED = "Joltik owned"
GALVANTULA_OWNED = "Galvantula owned"
FERROSEED_OWNED = "Ferroseed owned"
FERROTHORN_OWNED = "Ferrothorn owned"
KLINK_OWNED = "Klink owned"
KLANG_OWNED = "Klang owned"
KLINKLANG_OWNED = "Klinklang owned"
TYNAMO_OWNED = "Tynamo owned"
EELEKTRIK_OWNED = "Eelektrik owned"
EELEKTROSS_OWNED = "Eelektross owned"
ELGYEM_OWNED = "Elgyem owned"
BEHEEYEM_OWNED = "Beheeyem owned"
LITWICK_OWNED = "Litwick owned"
LAMPENT_OWNED = "Lampent owned"
CHANDELURE_OWNED = "Chandelure owned"
AXEW_OWNED = "Axew owned"
FRAXURE_OWNED = "Fraxure owned"
HAXORUS_OWNED = "Haxorus owned"
CUBCHOO_OWNED = "Cubchoo owned"
BEARTIC_OWNED = "Beartic owned"
CRYOGONAL_OWNED = "Cryogonal owned"
SHELMET_OWNED = "Shelmet owned"
ACCELGOR_OWNED = "Accelgor owned"
STUNFISK_OWNED = "Stunfisk owned"
MIENFOO_OWNED = "Mienfoo owned"
MIENSHAO_OWNED = "Mienshao owned"
DRUDDIGON_OWNED = "Druddigon owned"
GOLETT_OWNED = "Golett owned"
GOLURK_OWNED = "Golurk owned"
PAWNIARD_OWNED = "Pawniard owned"
BISHARP_OWNED = "Bisharp owned"
BOUFFALANT_OWNED = "Bouffalant owned"
RUFFLET_OWNED = "Rufflet owned"
BRAVIARY_OWNED = "Braviary owned"
VULLABY_OWNED = "Vullaby owned"
MANDIBUZZ_OWNED = "Mandibuzz owned"
HEATMOR_OWNED = "Heatmor owned"
DURANT_OWNED = "Durant owned"
DEINO_OWNED = "Deino owned"
ZWEILOUS_OWNED = "Zweilous owned"
HYDREIGON_OWNED = "Hydreigon owned"
LARVESTA_OWNED = "Larvesta owned"
VOLCARONA_OWNED = "Volcarona owned"
COBALION_OWNED = "Cobalion owned"
TERRAKION_OWNED = "Terrakion owned"
VIRIZION_OWNED = "Virizion owned"
TORNADUS_OWNED = "Tornadus owned"
THUNDURUS_OWNED = "Thundurus owned"
RESHIRAM_OWNED = "Reshiram owned"
ZEKROM_OWNED = "Zekrom owned"
LANDORUS_OWNED = "Landorus owned"
KYUREM_OWNED = "Kyurem owned"
KELDEO_OWNED = "Keldeo owned"
MELOETTA_OWNED = "Meloetta owned"
GENESECT_OWNED = "Genesect owned"
CHESPIN_OWNED = "Chespin owned"
QUILLADIN_OWNED = "Quilladin owned"
CHESNAUGHT_OWNED = "Chesnaught owned"
FENNEKIN_OWNED = "Fennekin owned"
BRAIXEN_OWNED = "Braixen owned"
DELPHOX_OWNED = "Delphox owned"
FROAKIE_OWNED = "Froakie owned"
FROGADIER_OWNED = "Frogadier owned"
GRENINJA_OWNED = "Greninja owned"
BUNNELBY_OWNED = "Bunnelby owned"
DIGGERSBY_OWNED = "Diggersby owned"
FLETCHLING_OWNED = "Fletchling owned"
FLETCHINDER_OWNED = "Fletchinder owned"
TALONFLAME_OWNED = "Talonflame owned"
SCATTERBUG_OWNED = "Scatterbug owned"
SPEWPA_OWNED = "Spewpa owned"
VIVILLON_OWNED = "Vivillon owned"
LITLEO_OWNED = "Litleo owned"
PYROAR_OWNED = "Pyroar owned"
FLABEBE_OWNED = "Flabébé owned"
FLOETTE_OWNED = "Floette owned"
FLORGES_OWNED = "Florges owned"
SKIDDO_OWNED = "Skiddo owned"
GOGOAT_OWNED = "Gogoat owned"
PANCHAM_OWNED = "Pancham owned"
PANGORO_OWNED = "Pangoro owned"
FURFROU_OWNED = "Furfrou owned"
ESPURR_OWNED = "Espurr owned"
MEOWSTIC_OWNED = "Meowstic owned"
HONEDGE_OWNED = "Honedge owned"
DOUBLADE_OWNED = "Doublade owned"
AEGISLASH_OWNED = "Aegislash owned"
SPRITZEE_OWNED = "Spritzee owned"
AROMATISSE_OWNED = "Aromatisse owned"
SWIRLIX_OWNED = "Swirlix owned"
SLURPUFF_OWNED = "Slurpuff owned"
INKAY_OWNED = "Inkay owned"
MALAMAR_OWNED = "Malamar owned"
BINACLE_OWNED = "Binacle owned"
BARBARACLE_OWNED = "Barbaracle owned"
SKRELP_OWNED = "Skrelp owned"
DRAGALGE_OWNED = "Dragalge owned"
CLAUNCHER_OWNED = "Clauncher owned"
CLAWITZER_OWNED = "Clawitzer owned"
HELIOPTILE_OWNED = "Helioptile owned"
HELIOLISK_OWNED = "Heliolisk owned"
TYRUNT_OWNED = "Tyrunt owned"
TYRANTRUM_OWNED = "Tyrantrum owned"
AMAURA_OWNED = "Amaura owned"
AURORUS_OWNED = "Aurorus owned"
SYLVEON_OWNED = "Sylveon owned"
HAWLUCHA_OWNED = "Hawlucha owned"
DEDENNE_OWNED = "Dedenne owned"
CARBINK_OWNED = "Carbink owned"
GOOMY_OWNED = "Goomy owned"
SLIGGOO_OWNED = "Sliggoo owned"
GOODRA_OWNED = "Goodra owned"
KLEFKI_OWNED = "Klefki owned"
PHANTUMP_OWNED = "Phantump owned"
TREVENANT_OWNED = "Trevenant owned"
PUMPKABOO_OWNED = "Pumpkaboo owned"
GOURGEIST_OWNED = "Gourgeist owned"
BERGMITE_OWNED = "Bergmite owned"
AVALUGG_OWNED = "Avalugg owned"
NOIBAT_OWNED = "Noibat owned"
NOIVERN_OWNED = "Noivern owned"
XERNEAS_OWNED = "Xerneas owned"
YVELTAL_OWNED = "Yveltal owned"
ZYGARDE_OWNED = "Zygarde owned"
DIANCIE_OWNED = "Diancie owned"
HOOPA_OWNED = "Hoopa owned"
VOLCANION_OWNED = "Volcanion owned"
ROWLET_OWNED = "Rowlet owned"
DARTRIX_OWNED = "Dartrix owned"
DECIDUEYE_OWNED = "Decidueye owned"
LITTEN_OWNED = "Litten owned"
TORRACAT_OWNED = "Torracat owned"
INCINEROAR_OWNED = "Incineroar owned"
POPPLIO_OWNED = "Popplio owned"
BRIONNE_OWNED = "Brionne owned"
PRIMARINA_OWNED = "Primarina owned"
PIKIPEK_OWNED = "Pikipek owned"
TRUMBEAK_OWNED = "Trumbeak owned"
TOUCANNON_OWNED = "Toucannon owned"
YUNGOOS_OWNED = "Yungoos owned"
GUMSHOOS_OWNED = "Gumshoos owned"
GRUBBIN_OWNED = "Grubbin owned"
CHARJABUG_OWNED = "Charjabug owned"
VIKAVOLT_OWNED = "Vikavolt owned"
CRABRAWLER_OWNED = "Crabrawler owned"
CRABOMINABLE_OWNED = "Crabominable owned"
ORICORIO_OWNED = "Oricorio owned"
CUTIEFLY_OWNED = "Cutiefly owned"
RIBOMBEE_OWNED = "Ribombee owned"
ROCKRUFF_OWNED = "Rockruff owned"
LYCANROC_OWNED = "Lycanroc owned"
WISHIWASHI_OWNED = "Wishiwashi owned"
MAREANIE_OWNED = "Mareanie owned"
TOXAPEX_OWNED = "Toxapex owned"
MUDBRAY_OWNED = "Mudbray owned"
MUDSDALE_OWNED = "Mudsdale owned"
DEWPIDER_OWNED = "Dewpider owned"
ARAQUANID_OWNED = "Araquanid owned"
FOMANTIS_OWNED = "Fomantis owned"
LURANTIS_OWNED = "Lurantis owned"
MORELULL_OWNED = "Morelull owned"
SHIINOTIC_OWNED = "Shiinotic owned"
SALANDIT_OWNED = "Salandit owned"
SALAZZLE_OWNED = "Salazzle owned"
STUFFUL_OWNED = "Stufful owned"
BEWEAR_OWNED = "Bewear owned"
BOUNSWEET_OWNED = "Bounsweet owned"
STEENEE_OWNED = "Steenee owned"
TSAREENA_OWNED = "Tsareena owned"
COMFEY_OWNED = "Comfey owned"
ORANGURU_OWNED = "Oranguru owned"
PASSIMIAN_OWNED = "Passimian owned"
WIMPOD_OWNED = "Wimpod owned"
GOLISOPOD_OWNED = "Golisopod owned"
SANDYGAST_OWNED = "Sandygast owned"
PALOSSAND_OWNED = "Palossand owned"
PYUKUMUKU_OWNED = "Pyukumuku owned"
TYPENULL_OWNED = "Type: Null owned"
SILVALLY_OWNED = "Silvally owned"
MINIOR_OWNED = "Minior owned"
KOMALA_OWNED = "Komala owned"
TURTONATOR_OWNED = "Turtonator owned"
TOGEDEMARU_OWNED = "Togedemaru owned"
MIMIKYU_OWNED = "Mimikyu owned"
BRUXISH_OWNED = "Bruxish owned"
DRAMPA_OWNED = "Drampa owned"
DHELMISE_OWNED = "Dhelmise owned"
JANGMO_O_OWNED = "Jangmo-o owned"
HAKAMO_O_OWNED = "Hakamo-o owned"
KOMMO_O_OWNED = "Kommo-o owned"
TAPUKOKO_OWNED = "Tapu Koko owned"
TAPULELE_OWNED = "Tapu Lele owned"
TAPUBULU_OWNED = "Tapu Bulu owned"
TAPUFINI_OWNED = "Tapu Fini owned"
COSMOG_OWNED = "Cosmog owned"
COSMOEM_OWNED = "Cosmoem owned"
SOLGALEO_OWNED = "Solgaleo owned"
LUNALA_OWNED = "Lunala owned"
NIHILEGO_OWNED = "Nihilego owned"
BUZZWOLE_OWNED = "Buzzwole owned"
PHEROMOSA_OWNED = "Pheromosa owned"
XURKITREE_OWNED = "Xurkitree owned"
CELESTEELA_OWNED = "Celesteela owned"
KARTANA_OWNED = "Kartana owned"
GUZZLORD_OWNED = "Guzzlord owned"
NECROZMA_OWNED = "Necrozma owned"
MAGEARNA_OWNED = "Magearna owned"
MARSHADOW_OWNED = "Marshadow owned"
POIPOLE_OWNED = "Poipole owned"
NAGANADEL_OWNED = "Naganadel owned"
STAKATAKA_OWNED = "Stakataka owned"
BLACEPHALON_OWNED = "Blacephalon owned"
ZERAORA_OWNED = "Zeraora owned"
MELTAN_OWNED = "Meltan owned"
MELMETAL_OWNED = "Melmetal owned"
GROOKEY_OWNED = "Grookey owned"
THWACKEY_OWNED = "Thwackey owned"
RILLABOOM_OWNED = "Rillaboom owned"
SCORBUNNY_OWNED = "Scorbunny owned"
RABOOT_OWNED = "Raboot owned"
CINDERACE_OWNED = "Cinderace owned"
SOBBLE_OWNED = "Sobble owned"
DRIZZILE_OWNED = "Drizzile owned"
INTELEON_OWNED = "Inteleon owned"
SKWOVET_OWNED = "Skwovet owned"
GREEDENT_OWNED = "Greedent owned"
ROOKIDEE_OWNED = "Rookidee owned"
CORVISQUIRE_OWNED = "Corvisquire owned"
CORVIKNIGHT_OWNED = "Corviknight owned"
BLIPBUG_OWNED = "Blipbug owned"
DOTTLER_OWNED = "Dottler owned"
ORBEETLE_OWNED = "Orbeetle owned"
NICKIT_OWNED = "Nickit owned"
THIEVUL_OWNED = "Thievul owned"
GOSSIFLEUR_OWNED = "Gossifleur owned"
ELDEGOSS_OWNED = "Eldegoss owned"
WOOLOO_OWNED = "Wooloo owned"
DUBWOOL_OWNED = "Dubwool owned"
CHEWTLE_OWNED = "Chewtle owned"
DREDNAW_OWNED = "Drednaw owned"
YAMPER_OWNED = "Yamper owned"
BOLTUND_OWNED = "Boltund owned"
ROLYCOLY_OWNED = "Rolycoly owned"
CARKOL_OWNED = "Carkol owned"
COALOSSAL_OWNED = "Coalossal owned"
APPLIN_OWNED = "Applin owned"
FLAPPLE_OWNED = "Flapple owned"
APPLETUN_OWNED = "Appletun owned"
SILICOBRA_OWNED = "Silicobra owned"
SANDACONDA_OWNED = "Sandaconda owned"
CRAMORANT_OWNED = "Cramorant owned"
ARROKUDA_OWNED = "Arrokuda owned"
BARRASKEWDA_OWNED = "Barraskewda owned"
TOXEL_OWNED = "Toxel owned"
TOXTRICITY_OWNED = "Toxtricity owned"
SIZZLIPEDE_OWNED = "Sizzlipede owned"
CENTISKORCH_OWNED = "Centiskorch owned"
CLOBBOPUS_OWNED = "Clobbopus owned"
GRAPPLOCT_OWNED = "Grapploct owned"
SINISTEA_OWNED = "Sinistea owned"
POLTEAGEIST_OWNED = "Polteageist owned"
HATENNA_OWNED = "Hatenna owned"
HATTREM_OWNED = "Hattrem owned"
HATTERENE_OWNED = "Hatterene owned"
IMPIDIMP_OWNED = "Impidimp owned"
MORGREM_OWNED = "Morgrem owned"
GRIMMSNARL_OWNED = "Grimmsnarl owned"
OBSTAGOON_OWNED = "Obstagoon owned"
PERRSERKER_OWNED = "Perrserker owned"
CURSOLA_OWNED = "Cursola owned"
SIRFETCHD_OWNED = "Sirfetch'd owned"
MRRIME_OWNED = "Mr. Rime owned"
RUNERIGUS_OWNED = "Runerigus owned"
MILCERY_OWNED = "Milcery owned"
ALCREMIE_OWNED = "Alcremie owned"
FALINKS_OWNED = "Falinks owned"
PINCURCHIN_OWNED = "Pincurchin owned"
SNOM_OWNED = "Snom owned"
FROSMOTH_OWNED = "Frosmoth owned"
STONJOURNER_OWNED = "Stonjourner owned"
EISCUE_OWNED = "Eiscue owned"
INDEEDEE_OWNED = "Indeedee owned"
MORPEKO_OWNED = "Morpeko owned"
CUFANT_OWNED = "Cufant owned"
COPPERAJAH_OWNED = "Copperajah owned"
DRACOZOLT_OWNED = "Dracozolt owned"
ARCTOZOLT_OWNED = "Arctozolt owned"
DRACOVISH_OWNED = "Dracovish owned"
ARCTOVISH_OWNED = "Arctovish owned"
DURALUDON_OWNED = "Duraludon owned"
DREEPY_OWNED = "Dreepy owned"
DRAKLOAK_OWNED = "Drakloak owned"
DRAGAPULT_OWNED = "Dragapult owned"
ZACIAN_OWNED = "Zacian owned"
ZAMAZENTA_OWNED = "Zamazenta owned"
ETERNATUS_OWNED = "Eternatus owned"
KUBFU_OWNED = "Kubfu owned"
URSHIFU_OWNED = "Urshifu owned"
ZARUDE_OWNED = "Zarude owned"
REGIELEKI_OWNED = "Regieleki owned"
REGIDRAGO_OWNED = "Regidrago owned"
GLASTRIER_OWNED = "Glastrier owned"
SPECTRIER_OWNED = "Spectrier owned"
CALYREX_OWNED = "Calyrex owned"

OWN_1_8 = "Own 1-8"
OWN_9_16 = "Own 9-16"
OWN_17_24 = "Own 17-24"
OWN_25_32 = "Own 25-32"
OWN_33_40 = "Own 33-40"
OWN_41_48 = "Own 41-48"
OWN_49_56 = "Own 49-56"
OWN_57_64 = "Own 57-64"
OWN_65_72 = "Own 65-72"
OWN_73_80 = "Own 73-80"
OWN_81_88 = "Own 81-88"
OWN_89_96 = "Own 89-96"
OWN_97_104 = "Own 97-104"
OWN_105_112 = "Own 105-112"
OWN_113_120 = "Own 113-120"
OWN_121_128 = "Own 121-128"
OWN_129_136 = "Own 129-136"
OWN_137_144 = "Own 137-144"
OWN_145_152 = "Own 145-152"
SEEN_1_8 = "Seen 1-8"
SEEN_9_16 = "Seen 9-16"
SEEN_17_24 = "Seen 17-24"
SEEN_25_32 = "Seen 25-32"
SEEN_33_40 = "Seen 33-40"
SEEN_41_48 = "Seen 41-48"
SEEN_49_56 = "Seen 49-56"
SEEN_57_64 = "Seen 57-64"
SEEN_65_72 = "Seen 65-72"
SEEN_73_80 = "Seen 73-80"
SEEN_81_88 = "Seen 81-88"
SEEN_89_96 = "Seen 89-96"
SEEN_97_104 = "Seen 97-104"
SEEN_105_112 = "Seen 105-112"
SEEN_113_120 = "Seen 113-120"
SEEN_121_128 = "Seen 121-128"
SEEN_129_136 = "Seen 129-136"
SEEN_137_144 = "Seen 137-144"
SEEN_145_152 = "Seen 145-152"



import os

FIREBASE_DATABASE_URL = os.environ.get("FIREBASE_DATABASE_URL", "")

FIREBASE_API_KEY = os.environ.get("FIREBASE_API_KEY", "")

FIREBASE_AUTH_DOMAIN = os.environ.get("FIREBASE_AUTH_DOMAIN", "")

FIREBASE_STORAGE_BUCKET = os.environ.get("FIREBASE_STORAGE_BUCKET", "")



from abc import ABC, abstractmethod
from typing import List, Optional, Union

from pydantic import BaseModel


class ChangeMeaning(BaseModel):

    #: Meaning of the change
    meaning: str

    #: Value associated with a meaning, for example the name of a location
    #: or the number of items in an inventory slot
    value: Union[str, int, bool]


class CartridgeInfo(ABC):
    """
    Info for a specific cartridge
    """

    @staticmethod
    @abstractmethod
    def byte_for_meaning(meaning: str) -> int:
        """
        Get the address corresponding to a specific meaning for a given
        cartridge.

        Raises
        ------
        ValueError
            If the meaning doesn't apply to this cartridge
        """

    @staticmethod
    @abstractmethod
    def meaning_for_byte_change(
        address: int,
        old_value: Optional[int],
        new_value: int,
    ) -> List[ChangeMeaning]:
        """
        Meanings corresponding to a change in byte value from one to another.

        There may be multiple meanings of a change, for example if the byte
        corresponds to several single-bit values
        """



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['gateau_api', 'gateau_api.game_ram', 'gateau_api.game_ram.pokemon']

package_data = \
{'': ['*']}

install_requires = \
['Pyrebase4>=4.5.0,<5.0.0',
 'bidict>=0.21.4,<0.22.0',
 'fastapi-camelcase>=1.0.5,<2.0.0',
 'fastapi>=0.71.0,<0.72.0',
 'uvicorn>=0.16.0,<0.17.0']

setup_kwargs = {
    'name': 'gateau-api',
    'version': '0.14.0',
    'description': '',
    'long_description': None,
    'author': 'Kevin Duff',
    'author_email': 'kevinkelduff@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
